#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 4.0.0-a53ec6ee1b (http://hl7.org/fhir/StructureDefinition/TestScript) on 2019-05-13.
#  2019, SMART Health IT.


from . import domainresource

class TestScript(domainresource.DomainResource):
    """ Describes a set of tests.

    A structured set of tests against a FHIR server or client implementation to
    determine compliance against the FHIR specification.
    """

    resource_type = "TestScript"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.contact = None
        """ Contact details for the publisher.
        List of `ContactDetail` items (represented as `dict` in JSON). """

        self.copyright = None
        """ Use and/or publishing restrictions.
        Type `str`. """

        self.date = None
        """ Date last changed.
        Type `FHIRDate` (represented as `str` in JSON). """

        self.description = None
        """ Natural language description of the test script.
        Type `str`. """

        self.destination = None
        """ An abstract server representing a destination or receiver in a
        message exchange.
        List of `TestScriptDestination` items (represented as `dict` in JSON). """

        self.experimental = None
        """ For testing purposes, not real usage.
        Type `bool`. """

        self.fixture = None
        """ Fixture in the test script - by reference (uri).
        List of `TestScriptFixture` items (represented as `dict` in JSON). """

        self.identifier = None
        """ Additional identifier for the test script.
        Type `Identifier` (represented as `dict` in JSON). """

        self.jurisdiction = None
        """ Intended jurisdiction for test script (if applicable).
        List of `CodeableConcept` items (represented as `dict` in JSON). """

        self.metadata = None
        """ Required capability that is assumed to function correctly on the
        FHIR server being tested.
        Type `TestScriptMetadata` (represented as `dict` in JSON). """

        self.name = None
        """ Name for this test script (computer friendly).
        Type `str`. """

        self.origin = None
        """ An abstract server representing a client or sender in a message
        exchange.
        List of `TestScriptOrigin` items (represented as `dict` in JSON). """

        self.profile = None
        """ Reference of the validation profile.
        List of `FHIRReference` items (represented as `dict` in JSON). """

        self.publisher = None
        """ Name of the publisher (organization or individual).
        Type `str`. """

        self.purpose = None
        """ Why this test script is defined.
        Type `str`. """

        self.setup = None
        """ A series of required setup operations before tests are executed.
        Type `TestScriptSetup` (represented as `dict` in JSON). """

        self.status = None
        """ draft | active | retired | unknown.
        Type `str`. """

        self.teardown = None
        """ A series of required clean up steps.
        Type `TestScriptTeardown` (represented as `dict` in JSON). """

        self.test = None
        """ A test in this script.
        List of `TestScriptTest` items (represented as `dict` in JSON). """

        self.title = None
        """ Name for this test script (human friendly).
        Type `str`. """

        self.url = None
        """ Canonical identifier for this test script, represented as a URI
        (globally unique).
        Type `str`. """

        self.useContext = None
        """ The context that the content is intended to support.
        List of `UsageContext` items (represented as `dict` in JSON). """

        self.variable = None
        """ Placeholder for evaluated elements.
        List of `TestScriptVariable` items (represented as `dict` in JSON). """

        self.version = None
        """ Business version of the test script.
        Type `str`. """

        super(TestScript, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(TestScript, self).elementProperties()
        js.extend([
            ("contact", "contact", contactdetail.ContactDetail, "ContactDetail", True, None, False),
            ("copyright", "copyright", str, "markdown", False, None, False),
            ("date", "date", fhirdate.FHIRDate, "dateTime", False, None, False),
            ("description", "description", str, "markdown", False, None, False),
            ("destination", "destination", TestScriptDestination, "TestScriptDestination", True, None, False),
            ("experimental", "experimental", bool, "boolean", False, None, False),
            ("fixture", "fixture", TestScriptFixture, "TestScriptFixture", True, None, False),
            ("identifier", "identifier", identifier.Identifier, "Identifier", False, None, False),
            ("jurisdiction", "jurisdiction", codeableconcept.CodeableConcept, "CodeableConcept", True, None, False),
            ("metadata", "metadata", TestScriptMetadata, "TestScriptMetadata", False, None, False),
            ("name", "name", str, "string", False, None, True),
            ("origin", "origin", TestScriptOrigin, "TestScriptOrigin", True, None, False),
            ("profile", "profile", fhirreference.FHIRReference, "Reference", True, None, False),
            ("publisher", "publisher", str, "string", False, None, False),
            ("purpose", "purpose", str, "markdown", False, None, False),
            ("setup", "setup", TestScriptSetup, "TestScriptSetup", False, None, False),
            ("status", "status", str, "code", False, None, True),
            ("teardown", "teardown", TestScriptTeardown, "TestScriptTeardown", False, None, False),
            ("test", "test", TestScriptTest, "TestScriptTest", True, None, False),
            ("title", "title", str, "string", False, None, False),
            ("url", "url", str, "uri", False, None, True),
            ("useContext", "useContext", usagecontext.UsageContext, "UsageContext", True, None, False),
            ("variable", "variable", TestScriptVariable, "TestScriptVariable", True, None, False),
            ("version", "version", str, "string", False, None, False),
        ])
        return js


from . import backboneelement

class TestScriptDestination(backboneelement.BackboneElement):
    """ An abstract server representing a destination or receiver in a message
    exchange.

    An abstract server used in operations within this test script in the
    destination element.
    """

    resource_type = "TestScriptDestination"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.index = None
        """ The index of the abstract destination server starting at 1.
        Type `int`. """

        self.profile = None
        """ FHIR-Server | FHIR-SDC-FormManager | FHIR-SDC-FormReceiver | FHIR-
        SDC-FormProcessor.
        Type `Coding` (represented as `dict` in JSON). """

        super(TestScriptDestination, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(TestScriptDestination, self).elementProperties()
        js.extend([
            ("index", "index", int, "integer", False, None, True),
            ("profile", "profile", coding.Coding, "Coding", False, None, True),
        ])
        return js


class TestScriptFixture(backboneelement.BackboneElement):
    """ Fixture in the test script - by reference (uri).

    Fixture in the test script - by reference (uri). All fixtures are required
    for the test script to execute.
    """

    resource_type = "TestScriptFixture"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.autocreate = None
        """ Whether or not to implicitly create the fixture during setup.
        Type `bool`. """

        self.autodelete = None
        """ Whether or not to implicitly delete the fixture during teardown.
        Type `bool`. """

        self.resource = None
        """ Reference of the resource.
        Type `FHIRReference` (represented as `dict` in JSON). """

        super(TestScriptFixture, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(TestScriptFixture, self).elementProperties()
        js.extend([
            ("autocreate", "autocreate", bool, "boolean", False, None, True),
            ("autodelete", "autodelete", bool, "boolean", False, None, True),
            ("resource", "resource", fhirreference.FHIRReference, "Reference", False, None, False),
        ])
        return js


class TestScriptMetadata(backboneelement.BackboneElement):
    """ Required capability that is assumed to function correctly on the FHIR
    server being tested.

    The required capability must exist and are assumed to function correctly on
    the FHIR server being tested.
    """

    resource_type = "TestScriptMetadata"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.capability = None
        """ Capabilities  that are assumed to function correctly on the FHIR
        server being tested.
        List of `TestScriptMetadataCapability` items (represented as `dict` in JSON). """

        self.link = None
        """ Links to the FHIR specification.
        List of `TestScriptMetadataLink` items (represented as `dict` in JSON). """

        super(TestScriptMetadata, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(TestScriptMetadata, self).elementProperties()
        js.extend([
            ("capability", "capability", TestScriptMetadataCapability, "TestScriptMetadataCapability", True, None, True),
            ("link", "link", TestScriptMetadataLink, "TestScriptMetadataLink", True, None, False),
        ])
        return js


class TestScriptMetadataCapability(backboneelement.BackboneElement):
    """ Capabilities  that are assumed to function correctly on the FHIR server
    being tested.

    Capabilities that must exist and are assumed to function correctly on the
    FHIR server being tested.
    """

    resource_type = "TestScriptMetadataCapability"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.capabilities = None
        """ Required Capability Statement.
        Type `str`. """

        self.description = None
        """ The expected capabilities of the server.
        Type `str`. """

        self.destination = None
        """ Which server these requirements apply to.
        Type `int`. """

        self.link = None
        """ Links to the FHIR specification.
        List of `str` items. """

        self.origin = None
        """ Which origin server these requirements apply to.
        List of `int` items. """

        self.required = None
        """ Are the capabilities required?.
        Type `bool`. """

        self.validated = None
        """ Are the capabilities validated?.
        Type `bool`. """

        super(TestScriptMetadataCapability, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(TestScriptMetadataCapability, self).elementProperties()
        js.extend([
            ("capabilities", "capabilities", str, "canonical", False, None, True),
            ("description", "description", str, "string", False, None, False),
            ("destination", "destination", int, "integer", False, None, False),
            ("link", "link", str, "uri", True, None, False),
            ("origin", "origin", int, "integer", True, None, False),
            ("required", "required", bool, "boolean", False, None, True),
            ("validated", "validated", bool, "boolean", False, None, True),
        ])
        return js


class TestScriptMetadataLink(backboneelement.BackboneElement):
    """ Links to the FHIR specification.

    A link to the FHIR specification that this test is covering.
    """

    resource_type = "TestScriptMetadataLink"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.description = None
        """ Short description.
        Type `str`. """

        self.url = None
        """ URL to the specification.
        Type `str`. """

        super(TestScriptMetadataLink, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(TestScriptMetadataLink, self).elementProperties()
        js.extend([
            ("description", "description", str, "string", False, None, False),
            ("url", "url", str, "uri", False, None, True),
        ])
        return js


class TestScriptOrigin(backboneelement.BackboneElement):
    """ An abstract server representing a client or sender in a message exchange.

    An abstract server used in operations within this test script in the origin
    element.
    """

    resource_type = "TestScriptOrigin"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.index = None
        """ The index of the abstract origin server starting at 1.
        Type `int`. """

        self.profile = None
        """ FHIR-Client | FHIR-SDC-FormFiller.
        Type `Coding` (represented as `dict` in JSON). """

        super(TestScriptOrigin, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(TestScriptOrigin, self).elementProperties()
        js.extend([
            ("index", "index", int, "integer", False, None, True),
            ("profile", "profile", coding.Coding, "Coding", False, None, True),
        ])
        return js


class TestScriptSetup(backboneelement.BackboneElement):
    """ A series of required setup operations before tests are executed.
    """

    resource_type = "TestScriptSetup"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.action = None
        """ A setup operation or assert to perform.
        List of `TestScriptSetupAction` items (represented as `dict` in JSON). """

        super(TestScriptSetup, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(TestScriptSetup, self).elementProperties()
        js.extend([
            ("action", "action", TestScriptSetupAction, "TestScriptSetupAction", True, None, True),
        ])
        return js


class TestScriptSetupAction(backboneelement.BackboneElement):
    """ A setup operation or assert to perform.

    Action would contain either an operation or an assertion.
    """

    resource_type = "TestScriptSetupAction"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.assert_fhir = None
        """ The assertion to perform.
        Type `TestScriptSetupActionAssert` (represented as `dict` in JSON). """

        self.operation = None
        """ The setup operation to perform.
        Type `TestScriptSetupActionOperation` (represented as `dict` in JSON). """

        super(TestScriptSetupAction, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(TestScriptSetupAction, self).elementProperties()
        js.extend([
            ("assert_fhir", "assert", TestScriptSetupActionAssert, "TestScriptSetupActionAssert", False, None, False),
            ("operation", "operation", TestScriptSetupActionOperation, "TestScriptSetupActionOperation", False, None, False),
        ])
        return js


class TestScriptSetupActionAssert(backboneelement.BackboneElement):
    """ The assertion to perform.

    Evaluates the results of previous operations to determine if the server
    under test behaves appropriately.
    """

    resource_type = "TestScriptSetupActionAssert"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.compareToSourceExpression = None
        """ The FHIRPath expression to evaluate against the source fixture.
        Type `str`. """

        self.compareToSourceId = None
        """ Id of the source fixture to be evaluated.
        Type `str`. """

        self.compareToSourcePath = None
        """ XPath or JSONPath expression to evaluate against the source fixture.
        Type `str`. """

        self.contentType = None
        """ Mime type to compare against the 'Content-Type' header.
        Type `str`. """

        self.description = None
        """ Tracking/reporting assertion description.
        Type `str`. """

        self.direction = None
        """ response | request.
        Type `str`. """

        self.expression = None
        """ The FHIRPath expression to be evaluated.
        Type `str`. """

        self.headerField = None
        """ HTTP header field name.
        Type `str`. """

        self.label = None
        """ Tracking/logging assertion label.
        Type `str`. """

        self.minimumId = None
        """ Fixture Id of minimum content resource.
        Type `str`. """

        self.navigationLinks = None
        """ Perform validation on navigation links?.
        Type `bool`. """

        self.operator = None
        """ equals | notEquals | in | notIn | greaterThan | lessThan | empty |
        notEmpty | contains | notContains | eval.
        Type `str`. """

        self.path = None
        """ XPath or JSONPath expression.
        Type `str`. """

        self.requestMethod = None
        """ delete | get | options | patch | post | put | head.
        Type `str`. """

        self.requestURL = None
        """ Request URL comparison value.
        Type `str`. """

        self.resource = None
        """ Resource type.
        Type `str`. """

        self.response = None
        """ okay | created | noContent | notModified | bad | forbidden |
        notFound | methodNotAllowed | conflict | gone | preconditionFailed
        | unprocessable.
        Type `str`. """

        self.responseCode = None
        """ HTTP response code to test.
        Type `str`. """

        self.sourceId = None
        """ Fixture Id of source expression or headerField.
        Type `str`. """

        self.validateProfileId = None
        """ Profile Id of validation profile reference.
        Type `str`. """

        self.value = None
        """ The value to compare to.
        Type `str`. """

        self.warningOnly = None
        """ Will this assert produce a warning only on error?.
        Type `bool`. """

        super(TestScriptSetupActionAssert, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(TestScriptSetupActionAssert, self).elementProperties()
        js.extend([
            ("compareToSourceExpression", "compareToSourceExpression", str, "string", False, None, False),
            ("compareToSourceId", "compareToSourceId", str, "string", False, None, False),
            ("compareToSourcePath", "compareToSourcePath", str, "string", False, None, False),
            ("contentType", "contentType", str, "code", False, None, False),
            ("description", "description", str, "string", False, None, False),
            ("direction", "direction", str, "code", False, None, False),
            ("expression", "expression", str, "string", False, None, False),
            ("headerField", "headerField", str, "string", False, None, False),
            ("label", "label", str, "string", False, None, False),
            ("minimumId", "minimumId", str, "string", False, None, False),
            ("navigationLinks", "navigationLinks", bool, "boolean", False, None, False),
            ("operator", "operator", str, "code", False, None, False),
            ("path", "path", str, "string", False, None, False),
            ("requestMethod", "requestMethod", str, "code", False, None, False),
            ("requestURL", "requestURL", str, "string", False, None, False),
            ("resource", "resource", str, "code", False, None, False),
            ("response", "response", str, "code", False, None, False),
            ("responseCode", "responseCode", str, "string", False, None, False),
            ("sourceId", "sourceId", str, "id", False, None, False),
            ("validateProfileId", "validateProfileId", str, "id", False, None, False),
            ("value", "value", str, "string", False, None, False),
            ("warningOnly", "warningOnly", bool, "boolean", False, None, True),
        ])
        return js


class TestScriptSetupActionOperation(backboneelement.BackboneElement):
    """ The setup operation to perform.

    The operation to perform.
    """

    resource_type = "TestScriptSetupActionOperation"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.accept = None
        """ Mime type to accept in the payload of the response, with charset
        etc..
        Type `str`. """

        self.contentType = None
        """ Mime type of the request payload contents, with charset etc..
        Type `str`. """

        self.description = None
        """ Tracking/reporting operation description.
        Type `str`. """

        self.destination = None
        """ Server responding to the request.
        Type `int`. """

        self.encodeRequestUrl = None
        """ Whether or not to send the request url in encoded format.
        Type `bool`. """

        self.label = None
        """ Tracking/logging operation label.
        Type `str`. """

        self.method = None
        """ delete | get | options | patch | post | put | head.
        Type `str`. """

        self.origin = None
        """ Server initiating the request.
        Type `int`. """

        self.params = None
        """ Explicitly defined path parameters.
        Type `str`. """

        self.requestHeader = None
        """ Each operation can have one or more header elements.
        List of `TestScriptSetupActionOperationRequestHeader` items (represented as `dict` in JSON). """

        self.requestId = None
        """ Fixture Id of mapped request.
        Type `str`. """

        self.resource = None
        """ Resource type.
        Type `str`. """

        self.responseId = None
        """ Fixture Id of mapped response.
        Type `str`. """

        self.sourceId = None
        """ Fixture Id of body for PUT and POST requests.
        Type `str`. """

        self.targetId = None
        """ Id of fixture used for extracting the [id],  [type], and [vid] for
        GET requests.
        Type `str`. """

        self.type = None
        """ The operation code type that will be executed.
        Type `Coding` (represented as `dict` in JSON). """

        self.url = None
        """ Request URL.
        Type `str`. """

        super(TestScriptSetupActionOperation, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(TestScriptSetupActionOperation, self).elementProperties()
        js.extend([
            ("accept", "accept", str, "code", False, None, False),
            ("contentType", "contentType", str, "code", False, None, False),
            ("description", "description", str, "string", False, None, False),
            ("destination", "destination", int, "integer", False, None, False),
            ("encodeRequestUrl", "encodeRequestUrl", bool, "boolean", False, None, True),
            ("label", "label", str, "string", False, None, False),
            ("method", "method", str, "code", False, None, False),
            ("origin", "origin", int, "integer", False, None, False),
            ("params", "params", str, "string", False, None, False),
            ("requestHeader", "requestHeader", TestScriptSetupActionOperationRequestHeader, "TestScriptSetupActionOperationRequestHeader", True, None, False),
            ("requestId", "requestId", str, "id", False, None, False),
            ("resource", "resource", str, "code", False, None, False),
            ("responseId", "responseId", str, "id", False, None, False),
            ("sourceId", "sourceId", str, "id", False, None, False),
            ("targetId", "targetId", str, "id", False, None, False),
            ("type", "type", coding.Coding, "Coding", False, None, False),
            ("url", "url", str, "string", False, None, False),
        ])
        return js


class TestScriptSetupActionOperationRequestHeader(backboneelement.BackboneElement):
    """ Each operation can have one or more header elements.

    Header elements would be used to set HTTP headers.
    """

    resource_type = "TestScriptSetupActionOperationRequestHeader"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.field = None
        """ HTTP header field name.
        Type `str`. """

        self.value = None
        """ HTTP headerfield value.
        Type `str`. """

        super(TestScriptSetupActionOperationRequestHeader, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(TestScriptSetupActionOperationRequestHeader, self).elementProperties()
        js.extend([
            ("field", "field", str, "string", False, None, True),
            ("value", "value", str, "string", False, None, True),
        ])
        return js


class TestScriptTeardown(backboneelement.BackboneElement):
    """ A series of required clean up steps.

    A series of operations required to clean up after all the tests are
    executed (successfully or otherwise).
    """

    resource_type = "TestScriptTeardown"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.action = None
        """ One or more teardown operations to perform.
        List of `TestScriptTeardownAction` items (represented as `dict` in JSON). """

        super(TestScriptTeardown, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(TestScriptTeardown, self).elementProperties()
        js.extend([
            ("action", "action", TestScriptTeardownAction, "TestScriptTeardownAction", True, None, True),
        ])
        return js


class TestScriptTeardownAction(backboneelement.BackboneElement):
    """ One or more teardown operations to perform.

    The teardown action will only contain an operation.
    """

    resource_type = "TestScriptTeardownAction"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.operation = None
        """ The teardown operation to perform.
        Type `TestScriptSetupActionOperation` (represented as `dict` in JSON). """

        super(TestScriptTeardownAction, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(TestScriptTeardownAction, self).elementProperties()
        js.extend([
            ("operation", "operation", TestScriptSetupActionOperation, "TestScriptSetupActionOperation", False, None, True),
        ])
        return js


class TestScriptTest(backboneelement.BackboneElement):
    """ A test in this script.
    """

    resource_type = "TestScriptTest"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.action = None
        """ A test operation or assert to perform.
        List of `TestScriptTestAction` items (represented as `dict` in JSON). """

        self.description = None
        """ Tracking/reporting short description of the test.
        Type `str`. """

        self.name = None
        """ Tracking/logging name of this test.
        Type `str`. """

        super(TestScriptTest, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(TestScriptTest, self).elementProperties()
        js.extend([
            ("action", "action", TestScriptTestAction, "TestScriptTestAction", True, None, True),
            ("description", "description", str, "string", False, None, False),
            ("name", "name", str, "string", False, None, False),
        ])
        return js


class TestScriptTestAction(backboneelement.BackboneElement):
    """ A test operation or assert to perform.

    Action would contain either an operation or an assertion.
    """

    resource_type = "TestScriptTestAction"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.assert_fhir = None
        """ The setup assertion to perform.
        Type `TestScriptSetupActionAssert` (represented as `dict` in JSON). """

        self.operation = None
        """ The setup operation to perform.
        Type `TestScriptSetupActionOperation` (represented as `dict` in JSON). """

        super(TestScriptTestAction, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(TestScriptTestAction, self).elementProperties()
        js.extend([
            ("assert_fhir", "assert", TestScriptSetupActionAssert, "TestScriptSetupActionAssert", False, None, False),
            ("operation", "operation", TestScriptSetupActionOperation, "TestScriptSetupActionOperation", False, None, False),
        ])
        return js


class TestScriptVariable(backboneelement.BackboneElement):
    """ Placeholder for evaluated elements.

    Variable is set based either on element value in response body or on header
    field value in the response headers.
    """

    resource_type = "TestScriptVariable"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.defaultValue = None
        """ Default, hard-coded, or user-defined value for this variable.
        Type `str`. """

        self.description = None
        """ Natural language description of the variable.
        Type `str`. """

        self.expression = None
        """ The FHIRPath expression against the fixture body.
        Type `str`. """

        self.headerField = None
        """ HTTP header field name for source.
        Type `str`. """

        self.hint = None
        """ Hint help text for default value to enter.
        Type `str`. """

        self.name = None
        """ Descriptive name for this variable.
        Type `str`. """

        self.path = None
        """ XPath or JSONPath against the fixture body.
        Type `str`. """

        self.sourceId = None
        """ Fixture Id of source expression or headerField within this variable.
        Type `str`. """

        super(TestScriptVariable, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(TestScriptVariable, self).elementProperties()
        js.extend([
            ("defaultValue", "defaultValue", str, "string", False, None, False),
            ("description", "description", str, "string", False, None, False),
            ("expression", "expression", str, "string", False, None, False),
            ("headerField", "headerField", str, "string", False, None, False),
            ("hint", "hint", str, "string", False, None, False),
            ("name", "name", str, "string", False, None, True),
            ("path", "path", str, "string", False, None, False),
            ("sourceId", "sourceId", str, "id", False, None, False),
        ])
        return js


import sys
try:
    from . import codeableconcept
except ImportError:
    codeableconcept = sys.modules[__package__ + '.codeableconcept']
try:
    from . import coding
except ImportError:
    coding = sys.modules[__package__ + '.coding']
try:
    from . import contactdetail
except ImportError:
    contactdetail = sys.modules[__package__ + '.contactdetail']
try:
    from . import fhirdate
except ImportError:
    fhirdate = sys.modules[__package__ + '.fhirdate']
try:
    from . import fhirreference
except ImportError:
    fhirreference = sys.modules[__package__ + '.fhirreference']
try:
    from . import identifier
except ImportError:
    identifier = sys.modules[__package__ + '.identifier']
try:
    from . import usagecontext
except ImportError:
    usagecontext = sys.modules[__package__ + '.usagecontext']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 4.0.0-a53ec6ee1b on 2019-05-13.
#  2019, SMART Health IT.


class FHIRElementFactory(object):
    """ Factory class to instantiate resources by resource name.
    """
    
    @classmethod
    def instantiate(cls, resource_type, jsondict):
        """ Instantiate a resource of the type correlating to "resource_type".
        
        :param str resource_type: The name/type of the resource to instantiate
        :param dict jsondict: The JSON dictionary to use for data
        :returns: A resource of the respective type or `Element`
        """
        if "Account" == resource_type:
            from . import account
            return account.Account(jsondict)
        if "AccountCoverage" == resource_type:
            from . import account
            return account.AccountCoverage(jsondict)
        if "AccountGuarantor" == resource_type:
            from . import account
            return account.AccountGuarantor(jsondict)
        if "ActivityDefinition" == resource_type:
            from . import activitydefinition
            return activitydefinition.ActivityDefinition(jsondict)
        if "ActivityDefinitionDynamicValue" == resource_type:
            from . import activitydefinition
            return activitydefinition.ActivityDefinitionDynamicValue(jsondict)
        if "ActivityDefinitionParticipant" == resource_type:
            from . import activitydefinition
            return activitydefinition.ActivityDefinitionParticipant(jsondict)
        if "Address" == resource_type:
            from . import address
            return address.Address(jsondict)
        if "AdverseEvent" == resource_type:
            from . import adverseevent
            return adverseevent.AdverseEvent(jsondict)
        if "AdverseEventSuspectEntity" == resource_type:
            from . import adverseevent
            return adverseevent.AdverseEventSuspectEntity(jsondict)
        if "AdverseEventSuspectEntityCausality" == resource_type:
            from . import adverseevent
            return adverseevent.AdverseEventSuspectEntityCausality(jsondict)
        if "Age" == resource_type:
            from . import age
            return age.Age(jsondict)
        if "AllergyIntolerance" == resource_type:
            from . import allergyintolerance
            return allergyintolerance.AllergyIntolerance(jsondict)
        if "AllergyIntoleranceReaction" == resource_type:
            from . import allergyintolerance
            return allergyintolerance.AllergyIntoleranceReaction(jsondict)
        if "Annotation" == resource_type:
            from . import annotation
            return annotation.Annotation(jsondict)
        if "Appointment" == resource_type:
            from . import appointment
            return appointment.Appointment(jsondict)
        if "AppointmentParticipant" == resource_type:
            from . import appointment
            return appointment.AppointmentParticipant(jsondict)
        if "AppointmentResponse" == resource_type:
            from . import appointmentresponse
            return appointmentresponse.AppointmentResponse(jsondict)
        if "Attachment" == resource_type:
            from . import attachment
            return attachment.Attachment(jsondict)
        if "AuditEvent" == resource_type:
            from . import auditevent
            return auditevent.AuditEvent(jsondict)
        if "AuditEventAgent" == resource_type:
            from . import auditevent
            return auditevent.AuditEventAgent(jsondict)
        if "AuditEventAgentNetwork" == resource_type:
            from . import auditevent
            return auditevent.AuditEventAgentNetwork(jsondict)
        if "AuditEventEntity" == resource_type:
            from . import auditevent
            return auditevent.AuditEventEntity(jsondict)
        if "AuditEventEntityDetail" == resource_type:
            from . import auditevent
            return auditevent.AuditEventEntityDetail(jsondict)
        if "AuditEventSource" == resource_type:
            from . import auditevent
            return auditevent.AuditEventSource(jsondict)
        if "BackboneElement" == resource_type:
            from . import backboneelement
            return backboneelement.BackboneElement(jsondict)
        if "Basic" == resource_type:
            from . import basic
            return basic.Basic(jsondict)
        if "Binary" == resource_type:
            from . import binary
            return binary.Binary(jsondict)
        if "BiologicallyDerivedProduct" == resource_type:
            from . import biologicallyderivedproduct
            return biologicallyderivedproduct.BiologicallyDerivedProduct(jsondict)
        if "BiologicallyDerivedProductCollection" == resource_type:
            from . import biologicallyderivedproduct
            return biologicallyderivedproduct.BiologicallyDerivedProductCollection(jsondict)
        if "BiologicallyDerivedProductManipulation" == resource_type:
            from . import biologicallyderivedproduct
            return biologicallyderivedproduct.BiologicallyDerivedProductManipulation(jsondict)
        if "BiologicallyDerivedProductProcessing" == resource_type:
            from . import biologicallyderivedproduct
            return biologicallyderivedproduct.BiologicallyDerivedProductProcessing(jsondict)
        if "BiologicallyDerivedProductStorage" == resource_type:
            from . import biologicallyderivedproduct
            return biologicallyderivedproduct.BiologicallyDerivedProductStorage(jsondict)
        if "BodyStructure" == resource_type:
            from . import bodystructure
            return bodystructure.BodyStructure(jsondict)
        if "Bundle" == resource_type:
            from . import bundle
            return bundle.Bundle(jsondict)
        if "BundleEntry" == resource_type:
            from . import bundle
            return bundle.BundleEntry(jsondict)
        if "BundleEntryRequest" == resource_type:
            from . import bundle
            return bundle.BundleEntryRequest(jsondict)
        if "BundleEntryResponse" == resource_type:
            from . import bundle
            return bundle.BundleEntryResponse(jsondict)
        if "BundleEntrySearch" == resource_type:
            from . import bundle
            return bundle.BundleEntrySearch(jsondict)
        if "BundleLink" == resource_type:
            from . import bundle
            return bundle.BundleLink(jsondict)
        if "CapabilityStatement" == resource_type:
            from . import capabilitystatement
            return capabilitystatement.CapabilityStatement(jsondict)
        if "CapabilityStatementDocument" == resource_type:
            from . import capabilitystatement
            return capabilitystatement.CapabilityStatementDocument(jsondict)
        if "CapabilityStatementImplementation" == resource_type:
            from . import capabilitystatement
            return capabilitystatement.CapabilityStatementImplementation(jsondict)
        if "CapabilityStatementMessaging" == resource_type:
            from . import capabilitystatement
            return capabilitystatement.CapabilityStatementMessaging(jsondict)
        if "CapabilityStatementMessagingEndpoint" == resource_type:
            from . import capabilitystatement
            return capabilitystatement.CapabilityStatementMessagingEndpoint(jsondict)
        if "CapabilityStatementMessagingSupportedMessage" == resource_type:
            from . import capabilitystatement
            return capabilitystatement.CapabilityStatementMessagingSupportedMessage(jsondict)
        if "CapabilityStatementRest" == resource_type:
            from . import capabilitystatement
            return capabilitystatement.CapabilityStatementRest(jsondict)
        if "CapabilityStatementRestInteraction" == resource_type:
            from . import capabilitystatement
            return capabilitystatement.CapabilityStatementRestInteraction(jsondict)
        if "CapabilityStatementRestResource" == resource_type:
            from . import capabilitystatement
            return capabilitystatement.CapabilityStatementRestResource(jsondict)
        if "CapabilityStatementRestResourceInteraction" == resource_type:
            from . import capabilitystatement
            return capabilitystatement.CapabilityStatementRestResourceInteraction(jsondict)
        if "CapabilityStatementRestResourceOperation" == resource_type:
            from . import capabilitystatement
            return capabilitystatement.CapabilityStatementRestResourceOperation(jsondict)
        if "CapabilityStatementRestResourceSearchParam" == resource_type:
            from . import capabilitystatement
            return capabilitystatement.CapabilityStatementRestResourceSearchParam(jsondict)
        if "CapabilityStatementRestSecurity" == resource_type:
            from . import capabilitystatement
            return capabilitystatement.CapabilityStatementRestSecurity(jsondict)
        if "CapabilityStatementSoftware" == resource_type:
            from . import capabilitystatement
            return capabilitystatement.CapabilityStatementSoftware(jsondict)
        if "CarePlan" == resource_type:
            from . import careplan
            return careplan.CarePlan(jsondict)
        if "CarePlanActivity" == resource_type:
            from . import careplan
            return careplan.CarePlanActivity(jsondict)
        if "CarePlanActivityDetail" == resource_type:
            from . import careplan
            return careplan.CarePlanActivityDetail(jsondict)
        if "CareTeam" == resource_type:
            from . import careteam
            return careteam.CareTeam(jsondict)
        if "CareTeamParticipant" == resource_type:
            from . import careteam
            return careteam.CareTeamParticipant(jsondict)
        if "CatalogEntry" == resource_type:
            from . import catalogentry
            return catalogentry.CatalogEntry(jsondict)
        if "CatalogEntryRelatedEntry" == resource_type:
            from . import catalogentry
            return catalogentry.CatalogEntryRelatedEntry(jsondict)
        if "ChargeItem" == resource_type:
            from . import chargeitem
            return chargeitem.ChargeItem(jsondict)
        if "ChargeItemDefinition" == resource_type:
            from . import chargeitemdefinition
            return chargeitemdefinition.ChargeItemDefinition(jsondict)
        if "ChargeItemDefinitionApplicability" == resource_type:
            from . import chargeitemdefinition
            return chargeitemdefinition.ChargeItemDefinitionApplicability(jsondict)
        if "ChargeItemDefinitionPropertyGroup" == resource_type:
            from . import chargeitemdefinition
            return chargeitemdefinition.ChargeItemDefinitionPropertyGroup(jsondict)
        if "ChargeItemDefinitionPropertyGroupPriceComponent" == resource_type:
            from . import chargeitemdefinition
            return chargeitemdefinition.ChargeItemDefinitionPropertyGroupPriceComponent(jsondict)
        if "ChargeItemPerformer" == resource_type:
            from . import chargeitem
            return chargeitem.ChargeItemPerformer(jsondict)
        if "Claim" == resource_type:
            from . import claim
            return claim.Claim(jsondict)
        if "ClaimAccident" == resource_type:
            from . import claim
            return claim.ClaimAccident(jsondict)
        if "ClaimCareTeam" == resource_type:
            from . import claim
            return claim.ClaimCareTeam(jsondict)
        if "ClaimDiagnosis" == resource_type:
            from . import claim
            return claim.ClaimDiagnosis(jsondict)
        if "ClaimInsurance" == resource_type:
            from . import claim
            return claim.ClaimInsurance(jsondict)
        if "ClaimItem" == resource_type:
            from . import claim
            return claim.ClaimItem(jsondict)
        if "ClaimItemDetail" == resource_type:
            from . import claim
            return claim.ClaimItemDetail(jsondict)
        if "ClaimItemDetailSubDetail" == resource_type:
            from . import claim
            return claim.ClaimItemDetailSubDetail(jsondict)
        if "ClaimPayee" == resource_type:
            from . import claim
            return claim.ClaimPayee(jsondict)
        if "ClaimProcedure" == resource_type:
            from . import claim
            return claim.ClaimProcedure(jsondict)
        if "ClaimRelated" == resource_type:
            from . import claim
            return claim.ClaimRelated(jsondict)
        if "ClaimResponse" == resource_type:
            from . import claimresponse
            return claimresponse.ClaimResponse(jsondict)
        if "ClaimResponseAddItem" == resource_type:
            from . import claimresponse
            return claimresponse.ClaimResponseAddItem(jsondict)
        if "ClaimResponseAddItemDetail" == resource_type:
            from . import claimresponse
            return claimresponse.ClaimResponseAddItemDetail(jsondict)
        if "ClaimResponseAddItemDetailSubDetail" == resource_type:
            from . import claimresponse
            return claimresponse.ClaimResponseAddItemDetailSubDetail(jsondict)
        if "ClaimResponseError" == resource_type:
            from . import claimresponse
            return claimresponse.ClaimResponseError(jsondict)
        if "ClaimResponseInsurance" == resource_type:
            from . import claimresponse
            return claimresponse.ClaimResponseInsurance(jsondict)
        if "ClaimResponseItem" == resource_type:
            from . import claimresponse
            return claimresponse.ClaimResponseItem(jsondict)
        if "ClaimResponseItemAdjudication" == resource_type:
            from . import claimresponse
            return claimresponse.ClaimResponseItemAdjudication(jsondict)
        if "ClaimResponseItemDetail" == resource_type:
            from . import claimresponse
            return claimresponse.ClaimResponseItemDetail(jsondict)
        if "ClaimResponseItemDetailSubDetail" == resource_type:
            from . import claimresponse
            return claimresponse.ClaimResponseItemDetailSubDetail(jsondict)
        if "ClaimResponsePayment" == resource_type:
            from . import claimresponse
            return claimresponse.ClaimResponsePayment(jsondict)
        if "ClaimResponseProcessNote" == resource_type:
            from . import claimresponse
            return claimresponse.ClaimResponseProcessNote(jsondict)
        if "ClaimResponseTotal" == resource_type:
            from . import claimresponse
            return claimresponse.ClaimResponseTotal(jsondict)
        if "ClaimSupportingInfo" == resource_type:
            from . import claim
            return claim.ClaimSupportingInfo(jsondict)
        if "ClinicalImpression" == resource_type:
            from . import clinicalimpression
            return clinicalimpression.ClinicalImpression(jsondict)
        if "ClinicalImpressionFinding" == resource_type:
            from . import clinicalimpression
            return clinicalimpression.ClinicalImpressionFinding(jsondict)
        if "ClinicalImpressionInvestigation" == resource_type:
            from . import clinicalimpression
            return clinicalimpression.ClinicalImpressionInvestigation(jsondict)
        if "CodeSystem" == resource_type:
            from . import codesystem
            return codesystem.CodeSystem(jsondict)
        if "CodeSystemConcept" == resource_type:
            from . import codesystem
            return codesystem.CodeSystemConcept(jsondict)
        if "CodeSystemConceptDesignation" == resource_type:
            from . import codesystem
            return codesystem.CodeSystemConceptDesignation(jsondict)
        if "CodeSystemConceptProperty" == resource_type:
            from . import codesystem
            return codesystem.CodeSystemConceptProperty(jsondict)
        if "CodeSystemFilter" == resource_type:
            from . import codesystem
            return codesystem.CodeSystemFilter(jsondict)
        if "CodeSystemProperty" == resource_type:
            from . import codesystem
            return codesystem.CodeSystemProperty(jsondict)
        if "CodeableConcept" == resource_type:
            from . import codeableconcept
            return codeableconcept.CodeableConcept(jsondict)
        if "Coding" == resource_type:
            from . import coding
            return coding.Coding(jsondict)
        if "Communication" == resource_type:
            from . import communication
            return communication.Communication(jsondict)
        if "CommunicationPayload" == resource_type:
            from . import communication
            return communication.CommunicationPayload(jsondict)
        if "CommunicationRequest" == resource_type:
            from . import communicationrequest
            return communicationrequest.CommunicationRequest(jsondict)
        if "CommunicationRequestPayload" == resource_type:
            from . import communicationrequest
            return communicationrequest.CommunicationRequestPayload(jsondict)
        if "CompartmentDefinition" == resource_type:
            from . import compartmentdefinition
            return compartmentdefinition.CompartmentDefinition(jsondict)
        if "CompartmentDefinitionResource" == resource_type:
            from . import compartmentdefinition
            return compartmentdefinition.CompartmentDefinitionResource(jsondict)
        if "Composition" == resource_type:
            from . import composition
            return composition.Composition(jsondict)
        if "CompositionAttester" == resource_type:
            from . import composition
            return composition.CompositionAttester(jsondict)
        if "CompositionEvent" == resource_type:
            from . import composition
            return composition.CompositionEvent(jsondict)
        if "CompositionRelatesTo" == resource_type:
            from . import composition
            return composition.CompositionRelatesTo(jsondict)
        if "CompositionSection" == resource_type:
            from . import composition
            return composition.CompositionSection(jsondict)
        if "ConceptMap" == resource_type:
            from . import conceptmap
            return conceptmap.ConceptMap(jsondict)
        if "ConceptMapGroup" == resource_type:
            from . import conceptmap
            return conceptmap.ConceptMapGroup(jsondict)
        if "ConceptMapGroupElement" == resource_type:
            from . import conceptmap
            return conceptmap.ConceptMapGroupElement(jsondict)
        if "ConceptMapGroupElementTarget" == resource_type:
            from . import conceptmap
            return conceptmap.ConceptMapGroupElementTarget(jsondict)
        if "ConceptMapGroupElementTargetDependsOn" == resource_type:
            from . import conceptmap
            return conceptmap.ConceptMapGroupElementTargetDependsOn(jsondict)
        if "ConceptMapGroupUnmapped" == resource_type:
            from . import conceptmap
            return conceptmap.ConceptMapGroupUnmapped(jsondict)
        if "Condition" == resource_type:
            from . import condition
            return condition.Condition(jsondict)
        if "ConditionEvidence" == resource_type:
            from . import condition
            return condition.ConditionEvidence(jsondict)
        if "ConditionStage" == resource_type:
            from . import condition
            return condition.ConditionStage(jsondict)
        if "Consent" == resource_type:
            from . import consent
            return consent.Consent(jsondict)
        if "ConsentPolicy" == resource_type:
            from . import consent
            return consent.ConsentPolicy(jsondict)
        if "ConsentProvision" == resource_type:
            from . import consent
            return consent.ConsentProvision(jsondict)
        if "ConsentProvisionActor" == resource_type:
            from . import consent
            return consent.ConsentProvisionActor(jsondict)
        if "ConsentProvisionData" == resource_type:
            from . import consent
            return consent.ConsentProvisionData(jsondict)
        if "ConsentVerification" == resource_type:
            from . import consent
            return consent.ConsentVerification(jsondict)
        if "ContactDetail" == resource_type:
            from . import contactdetail
            return contactdetail.ContactDetail(jsondict)
        if "ContactPoint" == resource_type:
            from . import contactpoint
            return contactpoint.ContactPoint(jsondict)
        if "Contract" == resource_type:
            from . import contract
            return contract.Contract(jsondict)
        if "ContractContentDefinition" == resource_type:
            from . import contract
            return contract.ContractContentDefinition(jsondict)
        if "ContractFriendly" == resource_type:
            from . import contract
            return contract.ContractFriendly(jsondict)
        if "ContractLegal" == resource_type:
            from . import contract
            return contract.ContractLegal(jsondict)
        if "ContractRule" == resource_type:
            from . import contract
            return contract.ContractRule(jsondict)
        if "ContractSigner" == resource_type:
            from . import contract
            return contract.ContractSigner(jsondict)
        if "ContractTerm" == resource_type:
            from . import contract
            return contract.ContractTerm(jsondict)
        if "ContractTermAction" == resource_type:
            from . import contract
            return contract.ContractTermAction(jsondict)
        if "ContractTermActionSubject" == resource_type:
            from . import contract
            return contract.ContractTermActionSubject(jsondict)
        if "ContractTermAsset" == resource_type:
            from . import contract
            return contract.ContractTermAsset(jsondict)
        if "ContractTermAssetContext" == resource_type:
            from . import contract
            return contract.ContractTermAssetContext(jsondict)
        if "ContractTermAssetValuedItem" == resource_type:
            from . import contract
            return contract.ContractTermAssetValuedItem(jsondict)
        if "ContractTermOffer" == resource_type:
            from . import contract
            return contract.ContractTermOffer(jsondict)
        if "ContractTermOfferAnswer" == resource_type:
            from . import contract
            return contract.ContractTermOfferAnswer(jsondict)
        if "ContractTermOfferParty" == resource_type:
            from . import contract
            return contract.ContractTermOfferParty(jsondict)
        if "ContractTermSecurityLabel" == resource_type:
            from . import contract
            return contract.ContractTermSecurityLabel(jsondict)
        if "Contributor" == resource_type:
            from . import contributor
            return contributor.Contributor(jsondict)
        if "Count" == resource_type:
            from . import count
            return count.Count(jsondict)
        if "Coverage" == resource_type:
            from . import coverage
            return coverage.Coverage(jsondict)
        if "CoverageClass" == resource_type:
            from . import coverage
            return coverage.CoverageClass(jsondict)
        if "CoverageCostToBeneficiary" == resource_type:
            from . import coverage
            return coverage.CoverageCostToBeneficiary(jsondict)
        if "CoverageCostToBeneficiaryException" == resource_type:
            from . import coverage
            return coverage.CoverageCostToBeneficiaryException(jsondict)
        if "CoverageEligibilityRequest" == resource_type:
            from . import coverageeligibilityrequest
            return coverageeligibilityrequest.CoverageEligibilityRequest(jsondict)
        if "CoverageEligibilityRequestInsurance" == resource_type:
            from . import coverageeligibilityrequest
            return coverageeligibilityrequest.CoverageEligibilityRequestInsurance(jsondict)
        if "CoverageEligibilityRequestItem" == resource_type:
            from . import coverageeligibilityrequest
            return coverageeligibilityrequest.CoverageEligibilityRequestItem(jsondict)
        if "CoverageEligibilityRequestItemDiagnosis" == resource_type:
            from . import coverageeligibilityrequest
            return coverageeligibilityrequest.CoverageEligibilityRequestItemDiagnosis(jsondict)
        if "CoverageEligibilityRequestSupportingInfo" == resource_type:
            from . import coverageeligibilityrequest
            return coverageeligibilityrequest.CoverageEligibilityRequestSupportingInfo(jsondict)
        if "CoverageEligibilityResponse" == resource_type:
            from . import coverageeligibilityresponse
            return coverageeligibilityresponse.CoverageEligibilityResponse(jsondict)
        if "CoverageEligibilityResponseError" == resource_type:
            from . import coverageeligibilityresponse
            return coverageeligibilityresponse.CoverageEligibilityResponseError(jsondict)
        if "CoverageEligibilityResponseInsurance" == resource_type:
            from . import coverageeligibilityresponse
            return coverageeligibilityresponse.CoverageEligibilityResponseInsurance(jsondict)
        if "CoverageEligibilityResponseInsuranceItem" == resource_type:
            from . import coverageeligibilityresponse
            return coverageeligibilityresponse.CoverageEligibilityResponseInsuranceItem(jsondict)
        if "CoverageEligibilityResponseInsuranceItemBenefit" == resource_type:
            from . import coverageeligibilityresponse
            return coverageeligibilityresponse.CoverageEligibilityResponseInsuranceItemBenefit(jsondict)
        if "DataRequirement" == resource_type:
            from . import datarequirement
            return datarequirement.DataRequirement(jsondict)
        if "DataRequirementCodeFilter" == resource_type:
            from . import datarequirement
            return datarequirement.DataRequirementCodeFilter(jsondict)
        if "DataRequirementDateFilter" == resource_type:
            from . import datarequirement
            return datarequirement.DataRequirementDateFilter(jsondict)
        if "DataRequirementSort" == resource_type:
            from . import datarequirement
            return datarequirement.DataRequirementSort(jsondict)
        if "DetectedIssue" == resource_type:
            from . import detectedissue
            return detectedissue.DetectedIssue(jsondict)
        if "DetectedIssueEvidence" == resource_type:
            from . import detectedissue
            return detectedissue.DetectedIssueEvidence(jsondict)
        if "DetectedIssueMitigation" == resource_type:
            from . import detectedissue
            return detectedissue.DetectedIssueMitigation(jsondict)
        if "Device" == resource_type:
            from . import device
            return device.Device(jsondict)
        if "DeviceDefinition" == resource_type:
            from . import devicedefinition
            return devicedefinition.DeviceDefinition(jsondict)
        if "DeviceDefinitionCapability" == resource_type:
            from . import devicedefinition
            return devicedefinition.DeviceDefinitionCapability(jsondict)
        if "DeviceDefinitionDeviceName" == resource_type:
            from . import devicedefinition
            return devicedefinition.DeviceDefinitionDeviceName(jsondict)
        if "DeviceDefinitionMaterial" == resource_type:
            from . import devicedefinition
            return devicedefinition.DeviceDefinitionMaterial(jsondict)
        if "DeviceDefinitionProperty" == resource_type:
            from . import devicedefinition
            return devicedefinition.DeviceDefinitionProperty(jsondict)
        if "DeviceDefinitionSpecialization" == resource_type:
            from . import devicedefinition
            return devicedefinition.DeviceDefinitionSpecialization(jsondict)
        if "DeviceDefinitionUdiDeviceIdentifier" == resource_type:
            from . import devicedefinition
            return devicedefinition.DeviceDefinitionUdiDeviceIdentifier(jsondict)
        if "DeviceDeviceName" == resource_type:
            from . import device
            return device.DeviceDeviceName(jsondict)
        if "DeviceMetric" == resource_type:
            from . import devicemetric
            return devicemetric.DeviceMetric(jsondict)
        if "DeviceMetricCalibration" == resource_type:
            from . import devicemetric
            return devicemetric.DeviceMetricCalibration(jsondict)
        if "DeviceProperty" == resource_type:
            from . import device
            return device.DeviceProperty(jsondict)
        if "DeviceRequest" == resource_type:
            from . import devicerequest
            return devicerequest.DeviceRequest(jsondict)
        if "DeviceRequestParameter" == resource_type:
            from . import devicerequest
            return devicerequest.DeviceRequestParameter(jsondict)
        if "DeviceSpecialization" == resource_type:
            from . import device
            return device.DeviceSpecialization(jsondict)
        if "DeviceUdiCarrier" == resource_type:
            from . import device
            return device.DeviceUdiCarrier(jsondict)
        if "DeviceUseStatement" == resource_type:
            from . import deviceusestatement
            return deviceusestatement.DeviceUseStatement(jsondict)
        if "DeviceVersion" == resource_type:
            from . import device
            return device.DeviceVersion(jsondict)
        if "DiagnosticReport" == resource_type:
            from . import diagnosticreport
            return diagnosticreport.DiagnosticReport(jsondict)
        if "DiagnosticReportMedia" == resource_type:
            from . import diagnosticreport
            return diagnosticreport.DiagnosticReportMedia(jsondict)
        if "Distance" == resource_type:
            from . import distance
            return distance.Distance(jsondict)
        if "DocumentManifest" == resource_type:
            from . import documentmanifest
            return documentmanifest.DocumentManifest(jsondict)
        if "DocumentManifestRelated" == resource_type:
            from . import documentmanifest
            return documentmanifest.DocumentManifestRelated(jsondict)
        if "DocumentReference" == resource_type:
            from . import documentreference
            return documentreference.DocumentReference(jsondict)
        if "DocumentReferenceContent" == resource_type:
            from . import documentreference
            return documentreference.DocumentReferenceContent(jsondict)
        if "DocumentReferenceContext" == resource_type:
            from . import documentreference
            return documentreference.DocumentReferenceContext(jsondict)
        if "DocumentReferenceRelatesTo" == resource_type:
            from . import documentreference
            return documentreference.DocumentReferenceRelatesTo(jsondict)
        if "DomainResource" == resource_type:
            from . import domainresource
            return domainresource.DomainResource(jsondict)
        if "Dosage" == resource_type:
            from . import dosage
            return dosage.Dosage(jsondict)
        if "DosageDoseAndRate" == resource_type:
            from . import dosage
            return dosage.DosageDoseAndRate(jsondict)
        if "Duration" == resource_type:
            from . import duration
            return duration.Duration(jsondict)
        if "EffectEvidenceSynthesis" == resource_type:
            from . import effectevidencesynthesis
            return effectevidencesynthesis.EffectEvidenceSynthesis(jsondict)
        if "EffectEvidenceSynthesisCertainty" == resource_type:
            from . import effectevidencesynthesis
            return effectevidencesynthesis.EffectEvidenceSynthesisCertainty(jsondict)
        if "EffectEvidenceSynthesisCertaintyCertaintySubcomponent" == resource_type:
            from . import effectevidencesynthesis
            return effectevidencesynthesis.EffectEvidenceSynthesisCertaintyCertaintySubcomponent(jsondict)
        if "EffectEvidenceSynthesisEffectEstimate" == resource_type:
            from . import effectevidencesynthesis
            return effectevidencesynthesis.EffectEvidenceSynthesisEffectEstimate(jsondict)
        if "EffectEvidenceSynthesisEffectEstimatePrecisionEstimate" == resource_type:
            from . import effectevidencesynthesis
            return effectevidencesynthesis.EffectEvidenceSynthesisEffectEstimatePrecisionEstimate(jsondict)
        if "EffectEvidenceSynthesisResultsByExposure" == resource_type:
            from . import effectevidencesynthesis
            return effectevidencesynthesis.EffectEvidenceSynthesisResultsByExposure(jsondict)
        if "EffectEvidenceSynthesisSampleSize" == resource_type:
            from . import effectevidencesynthesis
            return effectevidencesynthesis.EffectEvidenceSynthesisSampleSize(jsondict)
        if "Element" == resource_type:
            from . import element
            return element.Element(jsondict)
        if "ElementDefinition" == resource_type:
            from . import elementdefinition
            return elementdefinition.ElementDefinition(jsondict)
        if "ElementDefinitionBase" == resource_type:
            from . import elementdefinition
            return elementdefinition.ElementDefinitionBase(jsondict)
        if "ElementDefinitionBinding" == resource_type:
            from . import elementdefinition
            return elementdefinition.ElementDefinitionBinding(jsondict)
        if "ElementDefinitionConstraint" == resource_type:
            from . import elementdefinition
            return elementdefinition.ElementDefinitionConstraint(jsondict)
        if "ElementDefinitionExample" == resource_type:
            from . import elementdefinition
            return elementdefinition.ElementDefinitionExample(jsondict)
        if "ElementDefinitionMapping" == resource_type:
            from . import elementdefinition
            return elementdefinition.ElementDefinitionMapping(jsondict)
        if "ElementDefinitionSlicing" == resource_type:
            from . import elementdefinition
            return elementdefinition.ElementDefinitionSlicing(jsondict)
        if "ElementDefinitionSlicingDiscriminator" == resource_type:
            from . import elementdefinition
            return elementdefinition.ElementDefinitionSlicingDiscriminator(jsondict)
        if "ElementDefinitionType" == resource_type:
            from . import elementdefinition
            return elementdefinition.ElementDefinitionType(jsondict)
        if "Encounter" == resource_type:
            from . import encounter
            return encounter.Encounter(jsondict)
        if "EncounterClassHistory" == resource_type:
            from . import encounter
            return encounter.EncounterClassHistory(jsondict)
        if "EncounterDiagnosis" == resource_type:
            from . import encounter
            return encounter.EncounterDiagnosis(jsondict)
        if "EncounterHospitalization" == resource_type:
            from . import encounter
            return encounter.EncounterHospitalization(jsondict)
        if "EncounterLocation" == resource_type:
            from . import encounter
            return encounter.EncounterLocation(jsondict)
        if "EncounterParticipant" == resource_type:
            from . import encounter
            return encounter.EncounterParticipant(jsondict)
        if "EncounterStatusHistory" == resource_type:
            from . import encounter
            return encounter.EncounterStatusHistory(jsondict)
        if "Endpoint" == resource_type:
            from . import endpoint
            return endpoint.Endpoint(jsondict)
        if "EnrollmentRequest" == resource_type:
            from . import enrollmentrequest
            return enrollmentrequest.EnrollmentRequest(jsondict)
        if "EnrollmentResponse" == resource_type:
            from . import enrollmentresponse
            return enrollmentresponse.EnrollmentResponse(jsondict)
        if "EpisodeOfCare" == resource_type:
            from . import episodeofcare
            return episodeofcare.EpisodeOfCare(jsondict)
        if "EpisodeOfCareDiagnosis" == resource_type:
            from . import episodeofcare
            return episodeofcare.EpisodeOfCareDiagnosis(jsondict)
        if "EpisodeOfCareStatusHistory" == resource_type:
            from . import episodeofcare
            return episodeofcare.EpisodeOfCareStatusHistory(jsondict)
        if "EventDefinition" == resource_type:
            from . import eventdefinition
            return eventdefinition.EventDefinition(jsondict)
        if "Evidence" == resource_type:
            from . import evidence
            return evidence.Evidence(jsondict)
        if "EvidenceVariable" == resource_type:
            from . import evidencevariable
            return evidencevariable.EvidenceVariable(jsondict)
        if "EvidenceVariableCharacteristic" == resource_type:
            from . import evidencevariable
            return evidencevariable.EvidenceVariableCharacteristic(jsondict)
        if "ExampleScenario" == resource_type:
            from . import examplescenario
            return examplescenario.ExampleScenario(jsondict)
        if "ExampleScenarioActor" == resource_type:
            from . import examplescenario
            return examplescenario.ExampleScenarioActor(jsondict)
        if "ExampleScenarioInstance" == resource_type:
            from . import examplescenario
            return examplescenario.ExampleScenarioInstance(jsondict)
        if "ExampleScenarioInstanceContainedInstance" == resource_type:
            from . import examplescenario
            return examplescenario.ExampleScenarioInstanceContainedInstance(jsondict)
        if "ExampleScenarioInstanceVersion" == resource_type:
            from . import examplescenario
            return examplescenario.ExampleScenarioInstanceVersion(jsondict)
        if "ExampleScenarioProcess" == resource_type:
            from . import examplescenario
            return examplescenario.ExampleScenarioProcess(jsondict)
        if "ExampleScenarioProcessStep" == resource_type:
            from . import examplescenario
            return examplescenario.ExampleScenarioProcessStep(jsondict)
        if "ExampleScenarioProcessStepAlternative" == resource_type:
            from . import examplescenario
            return examplescenario.ExampleScenarioProcessStepAlternative(jsondict)
        if "ExampleScenarioProcessStepOperation" == resource_type:
            from . import examplescenario
            return examplescenario.ExampleScenarioProcessStepOperation(jsondict)
        if "ExplanationOfBenefit" == resource_type:
            from . import explanationofbenefit
            return explanationofbenefit.ExplanationOfBenefit(jsondict)
        if "ExplanationOfBenefitAccident" == resource_type:
            from . import explanationofbenefit
            return explanationofbenefit.ExplanationOfBenefitAccident(jsondict)
        if "ExplanationOfBenefitAddItem" == resource_type:
            from . import explanationofbenefit
            return explanationofbenefit.ExplanationOfBenefitAddItem(jsondict)
        if "ExplanationOfBenefitAddItemDetail" == resource_type:
            from . import explanationofbenefit
            return explanationofbenefit.ExplanationOfBenefitAddItemDetail(jsondict)
        if "ExplanationOfBenefitAddItemDetailSubDetail" == resource_type:
            from . import explanationofbenefit
            return explanationofbenefit.ExplanationOfBenefitAddItemDetailSubDetail(jsondict)
        if "ExplanationOfBenefitBenefitBalance" == resource_type:
            from . import explanationofbenefit
            return explanationofbenefit.ExplanationOfBenefitBenefitBalance(jsondict)
        if "ExplanationOfBenefitBenefitBalanceFinancial" == resource_type:
            from . import explanationofbenefit
            return explanationofbenefit.ExplanationOfBenefitBenefitBalanceFinancial(jsondict)
        if "ExplanationOfBenefitCareTeam" == resource_type:
            from . import explanationofbenefit
            return explanationofbenefit.ExplanationOfBenefitCareTeam(jsondict)
        if "ExplanationOfBenefitDiagnosis" == resource_type:
            from . import explanationofbenefit
            return explanationofbenefit.ExplanationOfBenefitDiagnosis(jsondict)
        if "ExplanationOfBenefitInsurance" == resource_type:
            from . import explanationofbenefit
            return explanationofbenefit.ExplanationOfBenefitInsurance(jsondict)
        if "ExplanationOfBenefitItem" == resource_type:
            from . import explanationofbenefit
            return explanationofbenefit.ExplanationOfBenefitItem(jsondict)
        if "ExplanationOfBenefitItemAdjudication" == resource_type:
            from . import explanationofbenefit
            return explanationofbenefit.ExplanationOfBenefitItemAdjudication(jsondict)
        if "ExplanationOfBenefitItemDetail" == resource_type:
            from . import explanationofbenefit
            return explanationofbenefit.ExplanationOfBenefitItemDetail(jsondict)
        if "ExplanationOfBenefitItemDetailSubDetail" == resource_type:
            from . import explanationofbenefit
            return explanationofbenefit.ExplanationOfBenefitItemDetailSubDetail(jsondict)
        if "ExplanationOfBenefitPayee" == resource_type:
            from . import explanationofbenefit
            return explanationofbenefit.ExplanationOfBenefitPayee(jsondict)
        if "ExplanationOfBenefitPayment" == resource_type:
            from . import explanationofbenefit
            return explanationofbenefit.ExplanationOfBenefitPayment(jsondict)
        if "ExplanationOfBenefitProcedure" == resource_type:
            from . import explanationofbenefit
            return explanationofbenefit.ExplanationOfBenefitProcedure(jsondict)
        if "ExplanationOfBenefitProcessNote" == resource_type:
            from . import explanationofbenefit
            return explanationofbenefit.ExplanationOfBenefitProcessNote(jsondict)
        if "ExplanationOfBenefitRelated" == resource_type:
            from . import explanationofbenefit
            return explanationofbenefit.ExplanationOfBenefitRelated(jsondict)
        if "ExplanationOfBenefitSupportingInfo" == resource_type:
            from . import explanationofbenefit
            return explanationofbenefit.ExplanationOfBenefitSupportingInfo(jsondict)
        if "ExplanationOfBenefitTotal" == resource_type:
            from . import explanationofbenefit
            return explanationofbenefit.ExplanationOfBenefitTotal(jsondict)
        if "Expression" == resource_type:
            from . import expression
            return expression.Expression(jsondict)
        if "Extension" == resource_type:
            from . import extension
            return extension.Extension(jsondict)
        if "FamilyMemberHistory" == resource_type:
            from . import familymemberhistory
            return familymemberhistory.FamilyMemberHistory(jsondict)
        if "FamilyMemberHistoryCondition" == resource_type:
            from . import familymemberhistory
            return familymemberhistory.FamilyMemberHistoryCondition(jsondict)
        if "Flag" == resource_type:
            from . import flag
            return flag.Flag(jsondict)
        if "Goal" == resource_type:
            from . import goal
            return goal.Goal(jsondict)
        if "GoalTarget" == resource_type:
            from . import goal
            return goal.GoalTarget(jsondict)
        if "GraphDefinition" == resource_type:
            from . import graphdefinition
            return graphdefinition.GraphDefinition(jsondict)
        if "GraphDefinitionLink" == resource_type:
            from . import graphdefinition
            return graphdefinition.GraphDefinitionLink(jsondict)
        if "GraphDefinitionLinkTarget" == resource_type:
            from . import graphdefinition
            return graphdefinition.GraphDefinitionLinkTarget(jsondict)
        if "GraphDefinitionLinkTargetCompartment" == resource_type:
            from . import graphdefinition
            return graphdefinition.GraphDefinitionLinkTargetCompartment(jsondict)
        if "Group" == resource_type:
            from . import group
            return group.Group(jsondict)
        if "GroupCharacteristic" == resource_type:
            from . import group
            return group.GroupCharacteristic(jsondict)
        if "GroupMember" == resource_type:
            from . import group
            return group.GroupMember(jsondict)
        if "GuidanceResponse" == resource_type:
            from . import guidanceresponse
            return guidanceresponse.GuidanceResponse(jsondict)
        if "HealthcareService" == resource_type:
            from . import healthcareservice
            return healthcareservice.HealthcareService(jsondict)
        if "HealthcareServiceAvailableTime" == resource_type:
            from . import healthcareservice
            return healthcareservice.HealthcareServiceAvailableTime(jsondict)
        if "HealthcareServiceEligibility" == resource_type:
            from . import healthcareservice
            return healthcareservice.HealthcareServiceEligibility(jsondict)
        if "HealthcareServiceNotAvailable" == resource_type:
            from . import healthcareservice
            return healthcareservice.HealthcareServiceNotAvailable(jsondict)
        if "HumanName" == resource_type:
            from . import humanname
            return humanname.HumanName(jsondict)
        if "Identifier" == resource_type:
            from . import identifier
            return identifier.Identifier(jsondict)
        if "ImagingStudy" == resource_type:
            from . import imagingstudy
            return imagingstudy.ImagingStudy(jsondict)
        if "ImagingStudySeries" == resource_type:
            from . import imagingstudy
            return imagingstudy.ImagingStudySeries(jsondict)
        if "ImagingStudySeriesInstance" == resource_type:
            from . import imagingstudy
            return imagingstudy.ImagingStudySeriesInstance(jsondict)
        if "ImagingStudySeriesPerformer" == resource_type:
            from . import imagingstudy
            return imagingstudy.ImagingStudySeriesPerformer(jsondict)
        if "Immunization" == resource_type:
            from . import immunization
            return immunization.Immunization(jsondict)
        if "ImmunizationEducation" == resource_type:
            from . import immunization
            return immunization.ImmunizationEducation(jsondict)
        if "ImmunizationEvaluation" == resource_type:
            from . import immunizationevaluation
            return immunizationevaluation.ImmunizationEvaluation(jsondict)
        if "ImmunizationPerformer" == resource_type:
            from . import immunization
            return immunization.ImmunizationPerformer(jsondict)
        if "ImmunizationProtocolApplied" == resource_type:
            from . import immunization
            return immunization.ImmunizationProtocolApplied(jsondict)
        if "ImmunizationReaction" == resource_type:
            from . import immunization
            return immunization.ImmunizationReaction(jsondict)
        if "ImmunizationRecommendation" == resource_type:
            from . import immunizationrecommendation
            return immunizationrecommendation.ImmunizationRecommendation(jsondict)
        if "ImmunizationRecommendationRecommendation" == resource_type:
            from . import immunizationrecommendation
            return immunizationrecommendation.ImmunizationRecommendationRecommendation(jsondict)
        if "ImmunizationRecommendationRecommendationDateCriterion" == resource_type:
            from . import immunizationrecommendation
            return immunizationrecommendation.ImmunizationRecommendationRecommendationDateCriterion(jsondict)
        if "ImplementationGuide" == resource_type:
            from . import implementationguide
            return implementationguide.ImplementationGuide(jsondict)
        if "ImplementationGuideDefinition" == resource_type:
            from . import implementationguide
            return implementationguide.ImplementationGuideDefinition(jsondict)
        if "ImplementationGuideDefinitionGrouping" == resource_type:
            from . import implementationguide
            return implementationguide.ImplementationGuideDefinitionGrouping(jsondict)
        if "ImplementationGuideDefinitionPage" == resource_type:
            from . import implementationguide
            return implementationguide.ImplementationGuideDefinitionPage(jsondict)
        if "ImplementationGuideDefinitionParameter" == resource_type:
            from . import implementationguide
            return implementationguide.ImplementationGuideDefinitionParameter(jsondict)
        if "ImplementationGuideDefinitionResource" == resource_type:
            from . import implementationguide
            return implementationguide.ImplementationGuideDefinitionResource(jsondict)
        if "ImplementationGuideDefinitionTemplate" == resource_type:
            from . import implementationguide
            return implementationguide.ImplementationGuideDefinitionTemplate(jsondict)
        if "ImplementationGuideDependsOn" == resource_type:
            from . import implementationguide
            return implementationguide.ImplementationGuideDependsOn(jsondict)
        if "ImplementationGuideGlobal" == resource_type:
            from . import implementationguide
            return implementationguide.ImplementationGuideGlobal(jsondict)
        if "ImplementationGuideManifest" == resource_type:
            from . import implementationguide
            return implementationguide.ImplementationGuideManifest(jsondict)
        if "ImplementationGuideManifestPage" == resource_type:
            from . import implementationguide
            return implementationguide.ImplementationGuideManifestPage(jsondict)
        if "ImplementationGuideManifestResource" == resource_type:
            from . import implementationguide
            return implementationguide.ImplementationGuideManifestResource(jsondict)
        if "InsurancePlan" == resource_type:
            from . import insuranceplan
            return insuranceplan.InsurancePlan(jsondict)
        if "InsurancePlanContact" == resource_type:
            from . import insuranceplan
            return insuranceplan.InsurancePlanContact(jsondict)
        if "InsurancePlanCoverage" == resource_type:
            from . import insuranceplan
            return insuranceplan.InsurancePlanCoverage(jsondict)
        if "InsurancePlanCoverageBenefit" == resource_type:
            from . import insuranceplan
            return insuranceplan.InsurancePlanCoverageBenefit(jsondict)
        if "InsurancePlanCoverageBenefitLimit" == resource_type:
            from . import insuranceplan
            return insuranceplan.InsurancePlanCoverageBenefitLimit(jsondict)
        if "InsurancePlanPlan" == resource_type:
            from . import insuranceplan
            return insuranceplan.InsurancePlanPlan(jsondict)
        if "InsurancePlanPlanGeneralCost" == resource_type:
            from . import insuranceplan
            return insuranceplan.InsurancePlanPlanGeneralCost(jsondict)
        if "InsurancePlanPlanSpecificCost" == resource_type:
            from . import insuranceplan
            return insuranceplan.InsurancePlanPlanSpecificCost(jsondict)
        if "InsurancePlanPlanSpecificCostBenefit" == resource_type:
            from . import insuranceplan
            return insuranceplan.InsurancePlanPlanSpecificCostBenefit(jsondict)
        if "InsurancePlanPlanSpecificCostBenefitCost" == resource_type:
            from . import insuranceplan
            return insuranceplan.InsurancePlanPlanSpecificCostBenefitCost(jsondict)
        if "Invoice" == resource_type:
            from . import invoice
            return invoice.Invoice(jsondict)
        if "InvoiceLineItem" == resource_type:
            from . import invoice
            return invoice.InvoiceLineItem(jsondict)
        if "InvoiceLineItemPriceComponent" == resource_type:
            from . import invoice
            return invoice.InvoiceLineItemPriceComponent(jsondict)
        if "InvoiceParticipant" == resource_type:
            from . import invoice
            return invoice.InvoiceParticipant(jsondict)
        if "Library" == resource_type:
            from . import library
            return library.Library(jsondict)
        if "Linkage" == resource_type:
            from . import linkage
            return linkage.Linkage(jsondict)
        if "LinkageItem" == resource_type:
            from . import linkage
            return linkage.LinkageItem(jsondict)
        if "List" == resource_type:
            from . import list
            return list.List(jsondict)
        if "ListEntry" == resource_type:
            from . import list
            return list.ListEntry(jsondict)
        if "Location" == resource_type:
            from . import location
            return location.Location(jsondict)
        if "LocationHoursOfOperation" == resource_type:
            from . import location
            return location.LocationHoursOfOperation(jsondict)
        if "LocationPosition" == resource_type:
            from . import location
            return location.LocationPosition(jsondict)
        if "MarketingStatus" == resource_type:
            from . import marketingstatus
            return marketingstatus.MarketingStatus(jsondict)
        if "Measure" == resource_type:
            from . import measure
            return measure.Measure(jsondict)
        if "MeasureGroup" == resource_type:
            from . import measure
            return measure.MeasureGroup(jsondict)
        if "MeasureGroupPopulation" == resource_type:
            from . import measure
            return measure.MeasureGroupPopulation(jsondict)
        if "MeasureGroupStratifier" == resource_type:
            from . import measure
            return measure.MeasureGroupStratifier(jsondict)
        if "MeasureGroupStratifierComponent" == resource_type:
            from . import measure
            return measure.MeasureGroupStratifierComponent(jsondict)
        if "MeasureReport" == resource_type:
            from . import measurereport
            return measurereport.MeasureReport(jsondict)
        if "MeasureReportGroup" == resource_type:
            from . import measurereport
            return measurereport.MeasureReportGroup(jsondict)
        if "MeasureReportGroupPopulation" == resource_type:
            from . import measurereport
            return measurereport.MeasureReportGroupPopulation(jsondict)
        if "MeasureReportGroupStratifier" == resource_type:
            from . import measurereport
            return measurereport.MeasureReportGroupStratifier(jsondict)
        if "MeasureReportGroupStratifierStratum" == resource_type:
            from . import measurereport
            return measurereport.MeasureReportGroupStratifierStratum(jsondict)
        if "MeasureReportGroupStratifierStratumComponent" == resource_type:
            from . import measurereport
            return measurereport.MeasureReportGroupStratifierStratumComponent(jsondict)
        if "MeasureReportGroupStratifierStratumPopulation" == resource_type:
            from . import measurereport
            return measurereport.MeasureReportGroupStratifierStratumPopulation(jsondict)
        if "MeasureSupplementalData" == resource_type:
            from . import measure
            return measure.MeasureSupplementalData(jsondict)
        if "Media" == resource_type:
            from . import media
            return media.Media(jsondict)
        if "Medication" == resource_type:
            from . import medication
            return medication.Medication(jsondict)
        if "MedicationAdministration" == resource_type:
            from . import medicationadministration
            return medicationadministration.MedicationAdministration(jsondict)
        if "MedicationAdministrationDosage" == resource_type:
            from . import medicationadministration
            return medicationadministration.MedicationAdministrationDosage(jsondict)
        if "MedicationAdministrationPerformer" == resource_type:
            from . import medicationadministration
            return medicationadministration.MedicationAdministrationPerformer(jsondict)
        if "MedicationBatch" == resource_type:
            from . import medication
            return medication.MedicationBatch(jsondict)
        if "MedicationDispense" == resource_type:
            from . import medicationdispense
            return medicationdispense.MedicationDispense(jsondict)
        if "MedicationDispensePerformer" == resource_type:
            from . import medicationdispense
            return medicationdispense.MedicationDispensePerformer(jsondict)
        if "MedicationDispenseSubstitution" == resource_type:
            from . import medicationdispense
            return medicationdispense.MedicationDispenseSubstitution(jsondict)
        if "MedicationIngredient" == resource_type:
            from . import medication
            return medication.MedicationIngredient(jsondict)
        if "MedicationKnowledge" == resource_type:
            from . import medicationknowledge
            return medicationknowledge.MedicationKnowledge(jsondict)
        if "MedicationKnowledgeAdministrationGuidelines" == resource_type:
            from . import medicationknowledge
            return medicationknowledge.MedicationKnowledgeAdministrationGuidelines(jsondict)
        if "MedicationKnowledgeAdministrationGuidelinesDosage" == resource_type:
            from . import medicationknowledge
            return medicationknowledge.MedicationKnowledgeAdministrationGuidelinesDosage(jsondict)
        if "MedicationKnowledgeAdministrationGuidelinesPatientCharacteristics" == resource_type:
            from . import medicationknowledge
            return medicationknowledge.MedicationKnowledgeAdministrationGuidelinesPatientCharacteristics(jsondict)
        if "MedicationKnowledgeCost" == resource_type:
            from . import medicationknowledge
            return medicationknowledge.MedicationKnowledgeCost(jsondict)
        if "MedicationKnowledgeDrugCharacteristic" == resource_type:
            from . import medicationknowledge
            return medicationknowledge.MedicationKnowledgeDrugCharacteristic(jsondict)
        if "MedicationKnowledgeIngredient" == resource_type:
            from . import medicationknowledge
            return medicationknowledge.MedicationKnowledgeIngredient(jsondict)
        if "MedicationKnowledgeKinetics" == resource_type:
            from . import medicationknowledge
            return medicationknowledge.MedicationKnowledgeKinetics(jsondict)
        if "MedicationKnowledgeMedicineClassification" == resource_type:
            from . import medicationknowledge
            return medicationknowledge.MedicationKnowledgeMedicineClassification(jsondict)
        if "MedicationKnowledgeMonitoringProgram" == resource_type:
            from . import medicationknowledge
            return medicationknowledge.MedicationKnowledgeMonitoringProgram(jsondict)
        if "MedicationKnowledgeMonograph" == resource_type:
            from . import medicationknowledge
            return medicationknowledge.MedicationKnowledgeMonograph(jsondict)
        if "MedicationKnowledgePackaging" == resource_type:
            from . import medicationknowledge
            return medicationknowledge.MedicationKnowledgePackaging(jsondict)
        if "MedicationKnowledgeRegulatory" == resource_type:
            from . import medicationknowledge
            return medicationknowledge.MedicationKnowledgeRegulatory(jsondict)
        if "MedicationKnowledgeRegulatoryMaxDispense" == resource_type:
            from . import medicationknowledge
            return medicationknowledge.MedicationKnowledgeRegulatoryMaxDispense(jsondict)
        if "MedicationKnowledgeRegulatorySchedule" == resource_type:
            from . import medicationknowledge
            return medicationknowledge.MedicationKnowledgeRegulatorySchedule(jsondict)
        if "MedicationKnowledgeRegulatorySubstitution" == resource_type:
            from . import medicationknowledge
            return medicationknowledge.MedicationKnowledgeRegulatorySubstitution(jsondict)
        if "MedicationKnowledgeRelatedMedicationKnowledge" == resource_type:
            from . import medicationknowledge
            return medicationknowledge.MedicationKnowledgeRelatedMedicationKnowledge(jsondict)
        if "MedicationRequest" == resource_type:
            from . import medicationrequest
            return medicationrequest.MedicationRequest(jsondict)
        if "MedicationRequestDispenseRequest" == resource_type:
            from . import medicationrequest
            return medicationrequest.MedicationRequestDispenseRequest(jsondict)
        if "MedicationRequestDispenseRequestInitialFill" == resource_type:
            from . import medicationrequest
            return medicationrequest.MedicationRequestDispenseRequestInitialFill(jsondict)
        if "MedicationRequestSubstitution" == resource_type:
            from . import medicationrequest
            return medicationrequest.MedicationRequestSubstitution(jsondict)
        if "MedicationStatement" == resource_type:
            from . import medicationstatement
            return medicationstatement.MedicationStatement(jsondict)
        if "MedicinalProduct" == resource_type:
            from . import medicinalproduct
            return medicinalproduct.MedicinalProduct(jsondict)
        if "MedicinalProductAuthorization" == resource_type:
            from . import medicinalproductauthorization
            return medicinalproductauthorization.MedicinalProductAuthorization(jsondict)
        if "MedicinalProductAuthorizationJurisdictionalAuthorization" == resource_type:
            from . import medicinalproductauthorization
            return medicinalproductauthorization.MedicinalProductAuthorizationJurisdictionalAuthorization(jsondict)
        if "MedicinalProductAuthorizationProcedure" == resource_type:
            from . import medicinalproductauthorization
            return medicinalproductauthorization.MedicinalProductAuthorizationProcedure(jsondict)
        if "MedicinalProductContraindication" == resource_type:
            from . import medicinalproductcontraindication
            return medicinalproductcontraindication.MedicinalProductContraindication(jsondict)
        if "MedicinalProductContraindicationOtherTherapy" == resource_type:
            from . import medicinalproductcontraindication
            return medicinalproductcontraindication.MedicinalProductContraindicationOtherTherapy(jsondict)
        if "MedicinalProductIndication" == resource_type:
            from . import medicinalproductindication
            return medicinalproductindication.MedicinalProductIndication(jsondict)
        if "MedicinalProductIndicationOtherTherapy" == resource_type:
            from . import medicinalproductindication
            return medicinalproductindication.MedicinalProductIndicationOtherTherapy(jsondict)
        if "MedicinalProductIngredient" == resource_type:
            from . import medicinalproductingredient
            return medicinalproductingredient.MedicinalProductIngredient(jsondict)
        if "MedicinalProductIngredientSpecifiedSubstance" == resource_type:
            from . import medicinalproductingredient
            return medicinalproductingredient.MedicinalProductIngredientSpecifiedSubstance(jsondict)
        if "MedicinalProductIngredientSpecifiedSubstanceStrength" == resource_type:
            from . import medicinalproductingredient
            return medicinalproductingredient.MedicinalProductIngredientSpecifiedSubstanceStrength(jsondict)
        if "MedicinalProductIngredientSpecifiedSubstanceStrengthReferenceStrength" == resource_type:
            from . import medicinalproductingredient
            return medicinalproductingredient.MedicinalProductIngredientSpecifiedSubstanceStrengthReferenceStrength(jsondict)
        if "MedicinalProductIngredientSubstance" == resource_type:
            from . import medicinalproductingredient
            return medicinalproductingredient.MedicinalProductIngredientSubstance(jsondict)
        if "MedicinalProductInteraction" == resource_type:
            from . import medicinalproductinteraction
            return medicinalproductinteraction.MedicinalProductInteraction(jsondict)
        if "MedicinalProductInteractionInteractant" == resource_type:
            from . import medicinalproductinteraction
            return medicinalproductinteraction.MedicinalProductInteractionInteractant(jsondict)
        if "MedicinalProductManufactured" == resource_type:
            from . import medicinalproductmanufactured
            return medicinalproductmanufactured.MedicinalProductManufactured(jsondict)
        if "MedicinalProductManufacturingBusinessOperation" == resource_type:
            from . import medicinalproduct
            return medicinalproduct.MedicinalProductManufacturingBusinessOperation(jsondict)
        if "MedicinalProductName" == resource_type:
            from . import medicinalproduct
            return medicinalproduct.MedicinalProductName(jsondict)
        if "MedicinalProductNameCountryLanguage" == resource_type:
            from . import medicinalproduct
            return medicinalproduct.MedicinalProductNameCountryLanguage(jsondict)
        if "MedicinalProductNameNamePart" == resource_type:
            from . import medicinalproduct
            return medicinalproduct.MedicinalProductNameNamePart(jsondict)
        if "MedicinalProductPackaged" == resource_type:
            from . import medicinalproductpackaged
            return medicinalproductpackaged.MedicinalProductPackaged(jsondict)
        if "MedicinalProductPackagedBatchIdentifier" == resource_type:
            from . import medicinalproductpackaged
            return medicinalproductpackaged.MedicinalProductPackagedBatchIdentifier(jsondict)
        if "MedicinalProductPackagedPackageItem" == resource_type:
            from . import medicinalproductpackaged
            return medicinalproductpackaged.MedicinalProductPackagedPackageItem(jsondict)
        if "MedicinalProductPharmaceutical" == resource_type:
            from . import medicinalproductpharmaceutical
            return medicinalproductpharmaceutical.MedicinalProductPharmaceutical(jsondict)
        if "MedicinalProductPharmaceuticalCharacteristics" == resource_type:
            from . import medicinalproductpharmaceutical
            return medicinalproductpharmaceutical.MedicinalProductPharmaceuticalCharacteristics(jsondict)
        if "MedicinalProductPharmaceuticalRouteOfAdministration" == resource_type:
            from . import medicinalproductpharmaceutical
            return medicinalproductpharmaceutical.MedicinalProductPharmaceuticalRouteOfAdministration(jsondict)
        if "MedicinalProductPharmaceuticalRouteOfAdministrationTargetSpecies" == resource_type:
            from . import medicinalproductpharmaceutical
            return medicinalproductpharmaceutical.MedicinalProductPharmaceuticalRouteOfAdministrationTargetSpecies(jsondict)
        if "MedicinalProductPharmaceuticalRouteOfAdministrationTargetSpeciesWithdrawalPeriod" == resource_type:
            from . import medicinalproductpharmaceutical
            return medicinalproductpharmaceutical.MedicinalProductPharmaceuticalRouteOfAdministrationTargetSpeciesWithdrawalPeriod(jsondict)
        if "MedicinalProductSpecialDesignation" == resource_type:
            from . import medicinalproduct
            return medicinalproduct.MedicinalProductSpecialDesignation(jsondict)
        if "MedicinalProductUndesirableEffect" == resource_type:
            from . import medicinalproductundesirableeffect
            return medicinalproductundesirableeffect.MedicinalProductUndesirableEffect(jsondict)
        if "MessageDefinition" == resource_type:
            from . import messagedefinition
            return messagedefinition.MessageDefinition(jsondict)
        if "MessageDefinitionAllowedResponse" == resource_type:
            from . import messagedefinition
            return messagedefinition.MessageDefinitionAllowedResponse(jsondict)
        if "MessageDefinitionFocus" == resource_type:
            from . import messagedefinition
            return messagedefinition.MessageDefinitionFocus(jsondict)
        if "MessageHeader" == resource_type:
            from . import messageheader
            return messageheader.MessageHeader(jsondict)
        if "MessageHeaderDestination" == resource_type:
            from . import messageheader
            return messageheader.MessageHeaderDestination(jsondict)
        if "MessageHeaderResponse" == resource_type:
            from . import messageheader
            return messageheader.MessageHeaderResponse(jsondict)
        if "MessageHeaderSource" == resource_type:
            from . import messageheader
            return messageheader.MessageHeaderSource(jsondict)
        if "Meta" == resource_type:
            from . import meta
            return meta.Meta(jsondict)
        if "MetadataResource" == resource_type:
            from . import metadataresource
            return metadataresource.MetadataResource(jsondict)
        if "MolecularSequence" == resource_type:
            from . import molecularsequence
            return molecularsequence.MolecularSequence(jsondict)
        if "MolecularSequenceQuality" == resource_type:
            from . import molecularsequence
            return molecularsequence.MolecularSequenceQuality(jsondict)
        if "MolecularSequenceQualityRoc" == resource_type:
            from . import molecularsequence
            return molecularsequence.MolecularSequenceQualityRoc(jsondict)
        if "MolecularSequenceReferenceSeq" == resource_type:
            from . import molecularsequence
            return molecularsequence.MolecularSequenceReferenceSeq(jsondict)
        if "MolecularSequenceRepository" == resource_type:
            from . import molecularsequence
            return molecularsequence.MolecularSequenceRepository(jsondict)
        if "MolecularSequenceStructureVariant" == resource_type:
            from . import molecularsequence
            return molecularsequence.MolecularSequenceStructureVariant(jsondict)
        if "MolecularSequenceStructureVariantInner" == resource_type:
            from . import molecularsequence
            return molecularsequence.MolecularSequenceStructureVariantInner(jsondict)
        if "MolecularSequenceStructureVariantOuter" == resource_type:
            from . import molecularsequence
            return molecularsequence.MolecularSequenceStructureVariantOuter(jsondict)
        if "MolecularSequenceVariant" == resource_type:
            from . import molecularsequence
            return molecularsequence.MolecularSequenceVariant(jsondict)
        if "Money" == resource_type:
            from . import money
            return money.Money(jsondict)
        if "NamingSystem" == resource_type:
            from . import namingsystem
            return namingsystem.NamingSystem(jsondict)
        if "NamingSystemUniqueId" == resource_type:
            from . import namingsystem
            return namingsystem.NamingSystemUniqueId(jsondict)
        if "Narrative" == resource_type:
            from . import narrative
            return narrative.Narrative(jsondict)
        if "NutritionOrder" == resource_type:
            from . import nutritionorder
            return nutritionorder.NutritionOrder(jsondict)
        if "NutritionOrderEnteralFormula" == resource_type:
            from . import nutritionorder
            return nutritionorder.NutritionOrderEnteralFormula(jsondict)
        if "NutritionOrderEnteralFormulaAdministration" == resource_type:
            from . import nutritionorder
            return nutritionorder.NutritionOrderEnteralFormulaAdministration(jsondict)
        if "NutritionOrderOralDiet" == resource_type:
            from . import nutritionorder
            return nutritionorder.NutritionOrderOralDiet(jsondict)
        if "NutritionOrderOralDietNutrient" == resource_type:
            from . import nutritionorder
            return nutritionorder.NutritionOrderOralDietNutrient(jsondict)
        if "NutritionOrderOralDietTexture" == resource_type:
            from . import nutritionorder
            return nutritionorder.NutritionOrderOralDietTexture(jsondict)
        if "NutritionOrderSupplement" == resource_type:
            from . import nutritionorder
            return nutritionorder.NutritionOrderSupplement(jsondict)
        if "Observation" == resource_type:
            from . import observation
            return observation.Observation(jsondict)
        if "ObservationComponent" == resource_type:
            from . import observation
            return observation.ObservationComponent(jsondict)
        if "ObservationDefinition" == resource_type:
            from . import observationdefinition
            return observationdefinition.ObservationDefinition(jsondict)
        if "ObservationDefinitionQualifiedInterval" == resource_type:
            from . import observationdefinition
            return observationdefinition.ObservationDefinitionQualifiedInterval(jsondict)
        if "ObservationDefinitionQuantitativeDetails" == resource_type:
            from . import observationdefinition
            return observationdefinition.ObservationDefinitionQuantitativeDetails(jsondict)
        if "ObservationReferenceRange" == resource_type:
            from . import observation
            return observation.ObservationReferenceRange(jsondict)
        if "OperationDefinition" == resource_type:
            from . import operationdefinition
            return operationdefinition.OperationDefinition(jsondict)
        if "OperationDefinitionOverload" == resource_type:
            from . import operationdefinition
            return operationdefinition.OperationDefinitionOverload(jsondict)
        if "OperationDefinitionParameter" == resource_type:
            from . import operationdefinition
            return operationdefinition.OperationDefinitionParameter(jsondict)
        if "OperationDefinitionParameterBinding" == resource_type:
            from . import operationdefinition
            return operationdefinition.OperationDefinitionParameterBinding(jsondict)
        if "OperationDefinitionParameterReferencedFrom" == resource_type:
            from . import operationdefinition
            return operationdefinition.OperationDefinitionParameterReferencedFrom(jsondict)
        if "OperationOutcome" == resource_type:
            from . import operationoutcome
            return operationoutcome.OperationOutcome(jsondict)
        if "OperationOutcomeIssue" == resource_type:
            from . import operationoutcome
            return operationoutcome.OperationOutcomeIssue(jsondict)
        if "Organization" == resource_type:
            from . import organization
            return organization.Organization(jsondict)
        if "OrganizationAffiliation" == resource_type:
            from . import organizationaffiliation
            return organizationaffiliation.OrganizationAffiliation(jsondict)
        if "OrganizationContact" == resource_type:
            from . import organization
            return organization.OrganizationContact(jsondict)
        if "ParameterDefinition" == resource_type:
            from . import parameterdefinition
            return parameterdefinition.ParameterDefinition(jsondict)
        if "Parameters" == resource_type:
            from . import parameters
            return parameters.Parameters(jsondict)
        if "ParametersParameter" == resource_type:
            from . import parameters
            return parameters.ParametersParameter(jsondict)
        if "Patient" == resource_type:
            from . import patient
            return patient.Patient(jsondict)
        if "PatientCommunication" == resource_type:
            from . import patient
            return patient.PatientCommunication(jsondict)
        if "PatientContact" == resource_type:
            from . import patient
            return patient.PatientContact(jsondict)
        if "PatientLink" == resource_type:
            from . import patient
            return patient.PatientLink(jsondict)
        if "PaymentNotice" == resource_type:
            from . import paymentnotice
            return paymentnotice.PaymentNotice(jsondict)
        if "PaymentReconciliation" == resource_type:
            from . import paymentreconciliation
            return paymentreconciliation.PaymentReconciliation(jsondict)
        if "PaymentReconciliationDetail" == resource_type:
            from . import paymentreconciliation
            return paymentreconciliation.PaymentReconciliationDetail(jsondict)
        if "PaymentReconciliationProcessNote" == resource_type:
            from . import paymentreconciliation
            return paymentreconciliation.PaymentReconciliationProcessNote(jsondict)
        if "Period" == resource_type:
            from . import period
            return period.Period(jsondict)
        if "Person" == resource_type:
            from . import person
            return person.Person(jsondict)
        if "PersonLink" == resource_type:
            from . import person
            return person.PersonLink(jsondict)
        if "PlanDefinition" == resource_type:
            from . import plandefinition
            return plandefinition.PlanDefinition(jsondict)
        if "PlanDefinitionAction" == resource_type:
            from . import plandefinition
            return plandefinition.PlanDefinitionAction(jsondict)
        if "PlanDefinitionActionCondition" == resource_type:
            from . import plandefinition
            return plandefinition.PlanDefinitionActionCondition(jsondict)
        if "PlanDefinitionActionDynamicValue" == resource_type:
            from . import plandefinition
            return plandefinition.PlanDefinitionActionDynamicValue(jsondict)
        if "PlanDefinitionActionParticipant" == resource_type:
            from . import plandefinition
            return plandefinition.PlanDefinitionActionParticipant(jsondict)
        if "PlanDefinitionActionRelatedAction" == resource_type:
            from . import plandefinition
            return plandefinition.PlanDefinitionActionRelatedAction(jsondict)
        if "PlanDefinitionGoal" == resource_type:
            from . import plandefinition
            return plandefinition.PlanDefinitionGoal(jsondict)
        if "PlanDefinitionGoalTarget" == resource_type:
            from . import plandefinition
            return plandefinition.PlanDefinitionGoalTarget(jsondict)
        if "Population" == resource_type:
            from . import population
            return population.Population(jsondict)
        if "Practitioner" == resource_type:
            from . import practitioner
            return practitioner.Practitioner(jsondict)
        if "PractitionerQualification" == resource_type:
            from . import practitioner
            return practitioner.PractitionerQualification(jsondict)
        if "PractitionerRole" == resource_type:
            from . import practitionerrole
            return practitionerrole.PractitionerRole(jsondict)
        if "PractitionerRoleAvailableTime" == resource_type:
            from . import practitionerrole
            return practitionerrole.PractitionerRoleAvailableTime(jsondict)
        if "PractitionerRoleNotAvailable" == resource_type:
            from . import practitionerrole
            return practitionerrole.PractitionerRoleNotAvailable(jsondict)
        if "Procedure" == resource_type:
            from . import procedure
            return procedure.Procedure(jsondict)
        if "ProcedureFocalDevice" == resource_type:
            from . import procedure
            return procedure.ProcedureFocalDevice(jsondict)
        if "ProcedurePerformer" == resource_type:
            from . import procedure
            return procedure.ProcedurePerformer(jsondict)
        if "ProdCharacteristic" == resource_type:
            from . import prodcharacteristic
            return prodcharacteristic.ProdCharacteristic(jsondict)
        if "ProductShelfLife" == resource_type:
            from . import productshelflife
            return productshelflife.ProductShelfLife(jsondict)
        if "Provenance" == resource_type:
            from . import provenance
            return provenance.Provenance(jsondict)
        if "ProvenanceAgent" == resource_type:
            from . import provenance
            return provenance.ProvenanceAgent(jsondict)
        if "ProvenanceEntity" == resource_type:
            from . import provenance
            return provenance.ProvenanceEntity(jsondict)
        if "Quantity" == resource_type:
            from . import quantity
            return quantity.Quantity(jsondict)
        if "Quantity" == resource_type:
            from . import quantity
            return quantity.Quantity(jsondict)
        if "Questionnaire" == resource_type:
            from . import questionnaire
            return questionnaire.Questionnaire(jsondict)
        if "QuestionnaireItem" == resource_type:
            from . import questionnaire
            return questionnaire.QuestionnaireItem(jsondict)
        if "QuestionnaireItemAnswerOption" == resource_type:
            from . import questionnaire
            return questionnaire.QuestionnaireItemAnswerOption(jsondict)
        if "QuestionnaireItemEnableWhen" == resource_type:
            from . import questionnaire
            return questionnaire.QuestionnaireItemEnableWhen(jsondict)
        if "QuestionnaireItemInitial" == resource_type:
            from . import questionnaire
            return questionnaire.QuestionnaireItemInitial(jsondict)
        if "QuestionnaireResponse" == resource_type:
            from . import questionnaireresponse
            return questionnaireresponse.QuestionnaireResponse(jsondict)
        if "QuestionnaireResponseItem" == resource_type:
            from . import questionnaireresponse
            return questionnaireresponse.QuestionnaireResponseItem(jsondict)
        if "QuestionnaireResponseItemAnswer" == resource_type:
            from . import questionnaireresponse
            return questionnaireresponse.QuestionnaireResponseItemAnswer(jsondict)
        if "Range" == resource_type:
            from . import range
            return range.Range(jsondict)
        if "Ratio" == resource_type:
            from . import ratio
            return ratio.Ratio(jsondict)
        if "Reference" == resource_type:
            from . import reference
            return reference.Reference(jsondict)
        if "RelatedArtifact" == resource_type:
            from . import relatedartifact
            return relatedartifact.RelatedArtifact(jsondict)
        if "RelatedPerson" == resource_type:
            from . import relatedperson
            return relatedperson.RelatedPerson(jsondict)
        if "RelatedPersonCommunication" == resource_type:
            from . import relatedperson
            return relatedperson.RelatedPersonCommunication(jsondict)
        if "RequestGroup" == resource_type:
            from . import requestgroup
            return requestgroup.RequestGroup(jsondict)
        if "RequestGroupAction" == resource_type:
            from . import requestgroup
            return requestgroup.RequestGroupAction(jsondict)
        if "RequestGroupActionCondition" == resource_type:
            from . import requestgroup
            return requestgroup.RequestGroupActionCondition(jsondict)
        if "RequestGroupActionRelatedAction" == resource_type:
            from . import requestgroup
            return requestgroup.RequestGroupActionRelatedAction(jsondict)
        if "ResearchDefinition" == resource_type:
            from . import researchdefinition
            return researchdefinition.ResearchDefinition(jsondict)
        if "ResearchElementDefinition" == resource_type:
            from . import researchelementdefinition
            return researchelementdefinition.ResearchElementDefinition(jsondict)
        if "ResearchElementDefinitionCharacteristic" == resource_type:
            from . import researchelementdefinition
            return researchelementdefinition.ResearchElementDefinitionCharacteristic(jsondict)
        if "ResearchStudy" == resource_type:
            from . import researchstudy
            return researchstudy.ResearchStudy(jsondict)
        if "ResearchStudyArm" == resource_type:
            from . import researchstudy
            return researchstudy.ResearchStudyArm(jsondict)
        if "ResearchStudyObjective" == resource_type:
            from . import researchstudy
            return researchstudy.ResearchStudyObjective(jsondict)
        if "ResearchSubject" == resource_type:
            from . import researchsubject
            return researchsubject.ResearchSubject(jsondict)
        if "Resource" == resource_type:
            from . import resource
            return resource.Resource(jsondict)
        if "RiskAssessment" == resource_type:
            from . import riskassessment
            return riskassessment.RiskAssessment(jsondict)
        if "RiskAssessmentPrediction" == resource_type:
            from . import riskassessment
            return riskassessment.RiskAssessmentPrediction(jsondict)
        if "RiskEvidenceSynthesis" == resource_type:
            from . import riskevidencesynthesis
            return riskevidencesynthesis.RiskEvidenceSynthesis(jsondict)
        if "RiskEvidenceSynthesisCertainty" == resource_type:
            from . import riskevidencesynthesis
            return riskevidencesynthesis.RiskEvidenceSynthesisCertainty(jsondict)
        if "RiskEvidenceSynthesisCertaintyCertaintySubcomponent" == resource_type:
            from . import riskevidencesynthesis
            return riskevidencesynthesis.RiskEvidenceSynthesisCertaintyCertaintySubcomponent(jsondict)
        if "RiskEvidenceSynthesisRiskEstimate" == resource_type:
            from . import riskevidencesynthesis
            return riskevidencesynthesis.RiskEvidenceSynthesisRiskEstimate(jsondict)
        if "RiskEvidenceSynthesisRiskEstimatePrecisionEstimate" == resource_type:
            from . import riskevidencesynthesis
            return riskevidencesynthesis.RiskEvidenceSynthesisRiskEstimatePrecisionEstimate(jsondict)
        if "RiskEvidenceSynthesisSampleSize" == resource_type:
            from . import riskevidencesynthesis
            return riskevidencesynthesis.RiskEvidenceSynthesisSampleSize(jsondict)
        if "SampledData" == resource_type:
            from . import sampleddata
            return sampleddata.SampledData(jsondict)
        if "Schedule" == resource_type:
            from . import schedule
            return schedule.Schedule(jsondict)
        if "SearchParameter" == resource_type:
            from . import searchparameter
            return searchparameter.SearchParameter(jsondict)
        if "SearchParameterComponent" == resource_type:
            from . import searchparameter
            return searchparameter.SearchParameterComponent(jsondict)
        if "ServiceRequest" == resource_type:
            from . import servicerequest
            return servicerequest.ServiceRequest(jsondict)
        if "Signature" == resource_type:
            from . import signature
            return signature.Signature(jsondict)
        if "Slot" == resource_type:
            from . import slot
            return slot.Slot(jsondict)
        if "Specimen" == resource_type:
            from . import specimen
            return specimen.Specimen(jsondict)
        if "SpecimenCollection" == resource_type:
            from . import specimen
            return specimen.SpecimenCollection(jsondict)
        if "SpecimenContainer" == resource_type:
            from . import specimen
            return specimen.SpecimenContainer(jsondict)
        if "SpecimenDefinition" == resource_type:
            from . import specimendefinition
            return specimendefinition.SpecimenDefinition(jsondict)
        if "SpecimenDefinitionTypeTested" == resource_type:
            from . import specimendefinition
            return specimendefinition.SpecimenDefinitionTypeTested(jsondict)
        if "SpecimenDefinitionTypeTestedContainer" == resource_type:
            from . import specimendefinition
            return specimendefinition.SpecimenDefinitionTypeTestedContainer(jsondict)
        if "SpecimenDefinitionTypeTestedContainerAdditive" == resource_type:
            from . import specimendefinition
            return specimendefinition.SpecimenDefinitionTypeTestedContainerAdditive(jsondict)
        if "SpecimenDefinitionTypeTestedHandling" == resource_type:
            from . import specimendefinition
            return specimendefinition.SpecimenDefinitionTypeTestedHandling(jsondict)
        if "SpecimenProcessing" == resource_type:
            from . import specimen
            return specimen.SpecimenProcessing(jsondict)
        if "StructureDefinition" == resource_type:
            from . import structuredefinition
            return structuredefinition.StructureDefinition(jsondict)
        if "StructureDefinitionContext" == resource_type:
            from . import structuredefinition
            return structuredefinition.StructureDefinitionContext(jsondict)
        if "StructureDefinitionDifferential" == resource_type:
            from . import structuredefinition
            return structuredefinition.StructureDefinitionDifferential(jsondict)
        if "StructureDefinitionMapping" == resource_type:
            from . import structuredefinition
            return structuredefinition.StructureDefinitionMapping(jsondict)
        if "StructureDefinitionSnapshot" == resource_type:
            from . import structuredefinition
            return structuredefinition.StructureDefinitionSnapshot(jsondict)
        if "StructureMap" == resource_type:
            from . import structuremap
            return structuremap.StructureMap(jsondict)
        if "StructureMapGroup" == resource_type:
            from . import structuremap
            return structuremap.StructureMapGroup(jsondict)
        if "StructureMapGroupInput" == resource_type:
            from . import structuremap
            return structuremap.StructureMapGroupInput(jsondict)
        if "StructureMapGroupRule" == resource_type:
            from . import structuremap
            return structuremap.StructureMapGroupRule(jsondict)
        if "StructureMapGroupRuleDependent" == resource_type:
            from . import structuremap
            return structuremap.StructureMapGroupRuleDependent(jsondict)
        if "StructureMapGroupRuleSource" == resource_type:
            from . import structuremap
            return structuremap.StructureMapGroupRuleSource(jsondict)
        if "StructureMapGroupRuleTarget" == resource_type:
            from . import structuremap
            return structuremap.StructureMapGroupRuleTarget(jsondict)
        if "StructureMapGroupRuleTargetParameter" == resource_type:
            from . import structuremap
            return structuremap.StructureMapGroupRuleTargetParameter(jsondict)
        if "StructureMapStructure" == resource_type:
            from . import structuremap
            return structuremap.StructureMapStructure(jsondict)
        if "Subscription" == resource_type:
            from . import subscription
            return subscription.Subscription(jsondict)
        if "SubscriptionChannel" == resource_type:
            from . import subscription
            return subscription.SubscriptionChannel(jsondict)
        if "Substance" == resource_type:
            from . import substance
            return substance.Substance(jsondict)
        if "SubstanceAmount" == resource_type:
            from . import substanceamount
            return substanceamount.SubstanceAmount(jsondict)
        if "SubstanceAmountReferenceRange" == resource_type:
            from . import substanceamount
            return substanceamount.SubstanceAmountReferenceRange(jsondict)
        if "SubstanceIngredient" == resource_type:
            from . import substance
            return substance.SubstanceIngredient(jsondict)
        if "SubstanceInstance" == resource_type:
            from . import substance
            return substance.SubstanceInstance(jsondict)
        if "SubstanceNucleicAcid" == resource_type:
            from . import substancenucleicacid
            return substancenucleicacid.SubstanceNucleicAcid(jsondict)
        if "SubstanceNucleicAcidSubunit" == resource_type:
            from . import substancenucleicacid
            return substancenucleicacid.SubstanceNucleicAcidSubunit(jsondict)
        if "SubstanceNucleicAcidSubunitLinkage" == resource_type:
            from . import substancenucleicacid
            return substancenucleicacid.SubstanceNucleicAcidSubunitLinkage(jsondict)
        if "SubstanceNucleicAcidSubunitSugar" == resource_type:
            from . import substancenucleicacid
            return substancenucleicacid.SubstanceNucleicAcidSubunitSugar(jsondict)
        if "SubstancePolymer" == resource_type:
            from . import substancepolymer
            return substancepolymer.SubstancePolymer(jsondict)
        if "SubstancePolymerMonomerSet" == resource_type:
            from . import substancepolymer
            return substancepolymer.SubstancePolymerMonomerSet(jsondict)
        if "SubstancePolymerMonomerSetStartingMaterial" == resource_type:
            from . import substancepolymer
            return substancepolymer.SubstancePolymerMonomerSetStartingMaterial(jsondict)
        if "SubstancePolymerRepeat" == resource_type:
            from . import substancepolymer
            return substancepolymer.SubstancePolymerRepeat(jsondict)
        if "SubstancePolymerRepeatRepeatUnit" == resource_type:
            from . import substancepolymer
            return substancepolymer.SubstancePolymerRepeatRepeatUnit(jsondict)
        if "SubstancePolymerRepeatRepeatUnitDegreeOfPolymerisation" == resource_type:
            from . import substancepolymer
            return substancepolymer.SubstancePolymerRepeatRepeatUnitDegreeOfPolymerisation(jsondict)
        if "SubstancePolymerRepeatRepeatUnitStructuralRepresentation" == resource_type:
            from . import substancepolymer
            return substancepolymer.SubstancePolymerRepeatRepeatUnitStructuralRepresentation(jsondict)
        if "SubstanceProtein" == resource_type:
            from . import substanceprotein
            return substanceprotein.SubstanceProtein(jsondict)
        if "SubstanceProteinSubunit" == resource_type:
            from . import substanceprotein
            return substanceprotein.SubstanceProteinSubunit(jsondict)
        if "SubstanceReferenceInformation" == resource_type:
            from . import substancereferenceinformation
            return substancereferenceinformation.SubstanceReferenceInformation(jsondict)
        if "SubstanceReferenceInformationClassification" == resource_type:
            from . import substancereferenceinformation
            return substancereferenceinformation.SubstanceReferenceInformationClassification(jsondict)
        if "SubstanceReferenceInformationGene" == resource_type:
            from . import substancereferenceinformation
            return substancereferenceinformation.SubstanceReferenceInformationGene(jsondict)
        if "SubstanceReferenceInformationGeneElement" == resource_type:
            from . import substancereferenceinformation
            return substancereferenceinformation.SubstanceReferenceInformationGeneElement(jsondict)
        if "SubstanceReferenceInformationTarget" == resource_type:
            from . import substancereferenceinformation
            return substancereferenceinformation.SubstanceReferenceInformationTarget(jsondict)
        if "SubstanceSourceMaterial" == resource_type:
            from . import substancesourcematerial
            return substancesourcematerial.SubstanceSourceMaterial(jsondict)
        if "SubstanceSourceMaterialFractionDescription" == resource_type:
            from . import substancesourcematerial
            return substancesourcematerial.SubstanceSourceMaterialFractionDescription(jsondict)
        if "SubstanceSourceMaterialOrganism" == resource_type:
            from . import substancesourcematerial
            return substancesourcematerial.SubstanceSourceMaterialOrganism(jsondict)
        if "SubstanceSourceMaterialOrganismAuthor" == resource_type:
            from . import substancesourcematerial
            return substancesourcematerial.SubstanceSourceMaterialOrganismAuthor(jsondict)
        if "SubstanceSourceMaterialOrganismHybrid" == resource_type:
            from . import substancesourcematerial
            return substancesourcematerial.SubstanceSourceMaterialOrganismHybrid(jsondict)
        if "SubstanceSourceMaterialOrganismOrganismGeneral" == resource_type:
            from . import substancesourcematerial
            return substancesourcematerial.SubstanceSourceMaterialOrganismOrganismGeneral(jsondict)
        if "SubstanceSourceMaterialPartDescription" == resource_type:
            from . import substancesourcematerial
            return substancesourcematerial.SubstanceSourceMaterialPartDescription(jsondict)
        if "SubstanceSpecification" == resource_type:
            from . import substancespecification
            return substancespecification.SubstanceSpecification(jsondict)
        if "SubstanceSpecificationMoiety" == resource_type:
            from . import substancespecification
            return substancespecification.SubstanceSpecificationMoiety(jsondict)
        if "SubstanceSpecificationName" == resource_type:
            from . import substancespecification
            return substancespecification.SubstanceSpecificationName(jsondict)
        if "SubstanceSpecificationNameOfficial" == resource_type:
            from . import substancespecification
            return substancespecification.SubstanceSpecificationNameOfficial(jsondict)
        if "SubstanceSpecificationProperty" == resource_type:
            from . import substancespecification
            return substancespecification.SubstanceSpecificationProperty(jsondict)
        if "SubstanceSpecificationRelationship" == resource_type:
            from . import substancespecification
            return substancespecification.SubstanceSpecificationRelationship(jsondict)
        if "SubstanceSpecificationStructure" == resource_type:
            from . import substancespecification
            return substancespecification.SubstanceSpecificationStructure(jsondict)
        if "SubstanceSpecificationStructureIsotope" == resource_type:
            from . import substancespecification
            return substancespecification.SubstanceSpecificationStructureIsotope(jsondict)
        if "SubstanceSpecificationStructureIsotopeMolecularWeight" == resource_type:
            from . import substancespecification
            return substancespecification.SubstanceSpecificationStructureIsotopeMolecularWeight(jsondict)
        if "SubstanceSpecificationStructureRepresentation" == resource_type:
            from . import substancespecification
            return substancespecification.SubstanceSpecificationStructureRepresentation(jsondict)
        if "SubstanceSpecificationstr" == resource_type:
            from . import substancespecification
            return substancespecification.SubstanceSpecificationstr(jsondict)
        if "SupplyDelivery" == resource_type:
            from . import supplydelivery
            return supplydelivery.SupplyDelivery(jsondict)
        if "SupplyDeliverySuppliedItem" == resource_type:
            from . import supplydelivery
            return supplydelivery.SupplyDeliverySuppliedItem(jsondict)
        if "SupplyRequest" == resource_type:
            from . import supplyrequest
            return supplyrequest.SupplyRequest(jsondict)
        if "SupplyRequestParameter" == resource_type:
            from . import supplyrequest
            return supplyrequest.SupplyRequestParameter(jsondict)
        if "Task" == resource_type:
            from . import task
            return task.Task(jsondict)
        if "TaskInput" == resource_type:
            from . import task
            return task.TaskInput(jsondict)
        if "TaskOutput" == resource_type:
            from . import task
            return task.TaskOutput(jsondict)
        if "TaskRestriction" == resource_type:
            from . import task
            return task.TaskRestriction(jsondict)
        if "TerminologyCapabilities" == resource_type:
            from . import terminologycapabilities
            return terminologycapabilities.TerminologyCapabilities(jsondict)
        if "TerminologyCapabilitiesClosure" == resource_type:
            from . import terminologycapabilities
            return terminologycapabilities.TerminologyCapabilitiesClosure(jsondict)
        if "TerminologyCapabilitiesCodeSystem" == resource_type:
            from . import terminologycapabilities
            return terminologycapabilities.TerminologyCapabilitiesCodeSystem(jsondict)
        if "TerminologyCapabilitiesCodeSystemVersion" == resource_type:
            from . import terminologycapabilities
            return terminologycapabilities.TerminologyCapabilitiesCodeSystemVersion(jsondict)
        if "TerminologyCapabilitiesCodeSystemVersionFilter" == resource_type:
            from . import terminologycapabilities
            return terminologycapabilities.TerminologyCapabilitiesCodeSystemVersionFilter(jsondict)
        if "TerminologyCapabilitiesExpansion" == resource_type:
            from . import terminologycapabilities
            return terminologycapabilities.TerminologyCapabilitiesExpansion(jsondict)
        if "TerminologyCapabilitiesExpansionParameter" == resource_type:
            from . import terminologycapabilities
            return terminologycapabilities.TerminologyCapabilitiesExpansionParameter(jsondict)
        if "TerminologyCapabilitiesImplementation" == resource_type:
            from . import terminologycapabilities
            return terminologycapabilities.TerminologyCapabilitiesImplementation(jsondict)
        if "TerminologyCapabilitiesSoftware" == resource_type:
            from . import terminologycapabilities
            return terminologycapabilities.TerminologyCapabilitiesSoftware(jsondict)
        if "TerminologyCapabilitiesTranslation" == resource_type:
            from . import terminologycapabilities
            return terminologycapabilities.TerminologyCapabilitiesTranslation(jsondict)
        if "TerminologyCapabilitiesValidateCode" == resource_type:
            from . import terminologycapabilities
            return terminologycapabilities.TerminologyCapabilitiesValidateCode(jsondict)
        if "TestReport" == resource_type:
            from . import testreport
            return testreport.TestReport(jsondict)
        if "TestReportParticipant" == resource_type:
            from . import testreport
            return testreport.TestReportParticipant(jsondict)
        if "TestReportSetup" == resource_type:
            from . import testreport
            return testreport.TestReportSetup(jsondict)
        if "TestReportSetupAction" == resource_type:
            from . import testreport
            return testreport.TestReportSetupAction(jsondict)
        if "TestReportSetupActionAssert" == resource_type:
            from . import testreport
            return testreport.TestReportSetupActionAssert(jsondict)
        if "TestReportSetupActionOperation" == resource_type:
            from . import testreport
            return testreport.TestReportSetupActionOperation(jsondict)
        if "TestReportTeardown" == resource_type:
            from . import testreport
            return testreport.TestReportTeardown(jsondict)
        if "TestReportTeardownAction" == resource_type:
            from . import testreport
            return testreport.TestReportTeardownAction(jsondict)
        if "TestReportTest" == resource_type:
            from . import testreport
            return testreport.TestReportTest(jsondict)
        if "TestReportTestAction" == resource_type:
            from . import testreport
            return testreport.TestReportTestAction(jsondict)
        if "TestScript" == resource_type:
            from . import testscript
            return testscript.TestScript(jsondict)
        if "TestScriptDestination" == resource_type:
            from . import testscript
            return testscript.TestScriptDestination(jsondict)
        if "TestScriptFixture" == resource_type:
            from . import testscript
            return testscript.TestScriptFixture(jsondict)
        if "TestScriptMetadata" == resource_type:
            from . import testscript
            return testscript.TestScriptMetadata(jsondict)
        if "TestScriptMetadataCapability" == resource_type:
            from . import testscript
            return testscript.TestScriptMetadataCapability(jsondict)
        if "TestScriptMetadataLink" == resource_type:
            from . import testscript
            return testscript.TestScriptMetadataLink(jsondict)
        if "TestScriptOrigin" == resource_type:
            from . import testscript
            return testscript.TestScriptOrigin(jsondict)
        if "TestScriptSetup" == resource_type:
            from . import testscript
            return testscript.TestScriptSetup(jsondict)
        if "TestScriptSetupAction" == resource_type:
            from . import testscript
            return testscript.TestScriptSetupAction(jsondict)
        if "TestScriptSetupActionAssert" == resource_type:
            from . import testscript
            return testscript.TestScriptSetupActionAssert(jsondict)
        if "TestScriptSetupActionOperation" == resource_type:
            from . import testscript
            return testscript.TestScriptSetupActionOperation(jsondict)
        if "TestScriptSetupActionOperationRequestHeader" == resource_type:
            from . import testscript
            return testscript.TestScriptSetupActionOperationRequestHeader(jsondict)
        if "TestScriptTeardown" == resource_type:
            from . import testscript
            return testscript.TestScriptTeardown(jsondict)
        if "TestScriptTeardownAction" == resource_type:
            from . import testscript
            return testscript.TestScriptTeardownAction(jsondict)
        if "TestScriptTest" == resource_type:
            from . import testscript
            return testscript.TestScriptTest(jsondict)
        if "TestScriptTestAction" == resource_type:
            from . import testscript
            return testscript.TestScriptTestAction(jsondict)
        if "TestScriptVariable" == resource_type:
            from . import testscript
            return testscript.TestScriptVariable(jsondict)
        if "Timing" == resource_type:
            from . import timing
            return timing.Timing(jsondict)
        if "TimingRepeat" == resource_type:
            from . import timing
            return timing.TimingRepeat(jsondict)
        if "TriggerDefinition" == resource_type:
            from . import triggerdefinition
            return triggerdefinition.TriggerDefinition(jsondict)
        if "UsageContext" == resource_type:
            from . import usagecontext
            return usagecontext.UsageContext(jsondict)
        if "ValueSet" == resource_type:
            from . import valueset
            return valueset.ValueSet(jsondict)
        if "ValueSetCompose" == resource_type:
            from . import valueset
            return valueset.ValueSetCompose(jsondict)
        if "ValueSetComposeInclude" == resource_type:
            from . import valueset
            return valueset.ValueSetComposeInclude(jsondict)
        if "ValueSetComposeIncludeConcept" == resource_type:
            from . import valueset
            return valueset.ValueSetComposeIncludeConcept(jsondict)
        if "ValueSetComposeIncludeConceptDesignation" == resource_type:
            from . import valueset
            return valueset.ValueSetComposeIncludeConceptDesignation(jsondict)
        if "ValueSetComposeIncludeFilter" == resource_type:
            from . import valueset
            return valueset.ValueSetComposeIncludeFilter(jsondict)
        if "ValueSetExpansion" == resource_type:
            from . import valueset
            return valueset.ValueSetExpansion(jsondict)
        if "ValueSetExpansionContains" == resource_type:
            from . import valueset
            return valueset.ValueSetExpansionContains(jsondict)
        if "ValueSetExpansionParameter" == resource_type:
            from . import valueset
            return valueset.ValueSetExpansionParameter(jsondict)
        if "VerificationResult" == resource_type:
            from . import verificationresult
            return verificationresult.VerificationResult(jsondict)
        if "VerificationResultAttestation" == resource_type:
            from . import verificationresult
            return verificationresult.VerificationResultAttestation(jsondict)
        if "VerificationResultPrimarySource" == resource_type:
            from . import verificationresult
            return verificationresult.VerificationResultPrimarySource(jsondict)
        if "VerificationResultValidator" == resource_type:
            from . import verificationresult
            return verificationresult.VerificationResultValidator(jsondict)
        if "VisionPrescription" == resource_type:
            from . import visionprescription
            return visionprescription.VisionPrescription(jsondict)
        if "VisionPrescriptionLensSpecification" == resource_type:
            from . import visionprescription
            return visionprescription.VisionPrescriptionLensSpecification(jsondict)
        if "VisionPrescriptionLensSpecificationPrism" == resource_type:
            from . import visionprescription
            return visionprescription.VisionPrescriptionLensSpecificationPrism(jsondict)
        from . import element
        return element.Element(jsondict)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 4.0.0-a53ec6ee1b on 2019-05-13.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json

from .fixtures import force_bytes
from .. import eventdefinition
from ..fhirdate import FHIRDate


@pytest.mark.usefixtures("base_settings")
class EventDefinitionTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("EventDefinition", js["resourceType"])
        return eventdefinition.EventDefinition(js)
    
    def testEventDefinition1(self):
        inst = self.instantiate_from("eventdefinition-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a EventDefinition instance")
        self.implEventDefinition1(inst)
        
        js = inst.as_json()
        self.assertEqual("EventDefinition", js["resourceType"])
        inst2 = eventdefinition.EventDefinition(js)
        self.implEventDefinition1(inst2)
    
    def implEventDefinition1(self, inst):
        self.assertEqual(force_bytes(inst.id), force_bytes("example"))
        self.assertEqual(force_bytes(inst.meta.tag[0].code), force_bytes("HTEST"))
        self.assertEqual(force_bytes(inst.meta.tag[0].display), force_bytes("test health data"))
        self.assertEqual(force_bytes(inst.meta.tag[0].system), force_bytes("http://terminology.hl7.org/CodeSystem/v3-ActReason"))
        self.assertEqual(force_bytes(inst.purpose), force_bytes("Monitor all admissions to Emergency"))
        self.assertEqual(force_bytes(inst.status), force_bytes("draft"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.trigger[0].condition.description), force_bytes("Encounter Location = emergency (active/completed encounters, current or previous)"))
        self.assertEqual(force_bytes(inst.trigger[0].condition.expression), force_bytes("(this | %previous).location.where(location = 'Location/emergency' and status in {'active', 'completed'}).exists()"))
        self.assertEqual(force_bytes(inst.trigger[0].condition.language), force_bytes("text/fhirpath"))
        self.assertEqual(force_bytes(inst.trigger[0].data[0].type), force_bytes("Encounter"))
        self.assertEqual(force_bytes(inst.trigger[0].name), force_bytes("monitor-emergency-admissions"))
        self.assertEqual(force_bytes(inst.trigger[0].type), force_bytes("named-event"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 4.0.0-a53ec6ee1b (http://hl7.org/fhir/StructureDefinition/BiologicallyDerivedProduct) on 2019-05-13.
#  2019, SMART Health IT.


from . import domainresource

class BiologicallyDerivedProduct(domainresource.DomainResource):
    """ A material substance originating from a biological entity.

    A material substance originating from a biological entity intended to be
    transplanted or infused
    into another (possibly the same) biological entity.
    """

    resource_type = "BiologicallyDerivedProduct"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.collection = None
        """ How this product was collected.
        Type `BiologicallyDerivedProductCollection` (represented as `dict` in JSON). """

        self.identifier = None
        """ External ids for this item.
        List of `Identifier` items (represented as `dict` in JSON). """

        self.manipulation = None
        """ Any manipulation of product post-collection.
        Type `BiologicallyDerivedProductManipulation` (represented as `dict` in JSON). """

        self.parent = None
        """ BiologicallyDerivedProduct parent.
        List of `FHIRReference` items (represented as `dict` in JSON). """

        self.processing = None
        """ Any processing of the product during collection.
        List of `BiologicallyDerivedProductProcessing` items (represented as `dict` in JSON). """

        self.productCategory = None
        """ organ | tissue | fluid | cells | biologicalAgent.
        Type `str`. """

        self.productCode = None
        """ What this biologically derived product is.
        Type `CodeableConcept` (represented as `dict` in JSON). """

        self.quantity = None
        """ The amount of this biologically derived product.
        Type `int`. """

        self.request = None
        """ Procedure request.
        List of `FHIRReference` items (represented as `dict` in JSON). """

        self.status = None
        """ available | unavailable.
        Type `str`. """

        self.storage = None
        """ Product storage.
        List of `BiologicallyDerivedProductStorage` items (represented as `dict` in JSON). """

        super(BiologicallyDerivedProduct, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(BiologicallyDerivedProduct, self).elementProperties()
        js.extend([
            ("collection", "collection", BiologicallyDerivedProductCollection, "BiologicallyDerivedProductCollection", False, None, False),
            ("identifier", "identifier", identifier.Identifier, "Identifier", True, None, False),
            ("manipulation", "manipulation", BiologicallyDerivedProductManipulation, "BiologicallyDerivedProductManipulation", False, None, False),
            ("parent", "parent", fhirreference.FHIRReference, "Reference", True, None, False),
            ("processing", "processing", BiologicallyDerivedProductProcessing, "BiologicallyDerivedProductProcessing", True, None, False),
            ("productCategory", "productCategory", str, "code", False, None, False),
            ("productCode", "productCode", codeableconcept.CodeableConcept, "CodeableConcept", False, None, False),
            ("quantity", "quantity", int, "integer", False, None, False),
            ("request", "request", fhirreference.FHIRReference, "Reference", True, None, False),
            ("status", "status", str, "code", False, None, False),
            ("storage", "storage", BiologicallyDerivedProductStorage, "BiologicallyDerivedProductStorage", True, None, False),
        ])
        return js


from . import backboneelement

class BiologicallyDerivedProductCollection(backboneelement.BackboneElement):
    """ How this product was collected.
    """

    resource_type = "BiologicallyDerivedProductCollection"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.collectedDateTime = None
        """ Time of product collection.
        Type `FHIRDate` (represented as `str` in JSON). """

        self.collectedPeriod = None
        """ Time of product collection.
        Type `Period` (represented as `dict` in JSON). """

        self.collector = None
        """ Individual performing collection.
        Type `FHIRReference` (represented as `dict` in JSON). """

        self.source = None
        """ Who is product from.
        Type `FHIRReference` (represented as `dict` in JSON). """

        super(BiologicallyDerivedProductCollection, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(BiologicallyDerivedProductCollection, self).elementProperties()
        js.extend([
            ("collectedDateTime", "collectedDateTime", fhirdate.FHIRDate, "dateTime", False, "collected", False),
            ("collectedPeriod", "collectedPeriod", period.Period, "Period", False, "collected", False),
            ("collector", "collector", fhirreference.FHIRReference, "Reference", False, None, False),
            ("source", "source", fhirreference.FHIRReference, "Reference", False, None, False),
        ])
        return js


class BiologicallyDerivedProductManipulation(backboneelement.BackboneElement):
    """ Any manipulation of product post-collection.

    Any manipulation of product post-collection that is intended to alter the
    product.  For example a buffy-coat enrichment or CD8 reduction of
    Peripheral Blood Stem Cells to make it more suitable for infusion.
    """

    resource_type = "BiologicallyDerivedProductManipulation"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.description = None
        """ Description of manipulation.
        Type `str`. """

        self.timeDateTime = None
        """ Time of manipulation.
        Type `FHIRDate` (represented as `str` in JSON). """

        self.timePeriod = None
        """ Time of manipulation.
        Type `Period` (represented as `dict` in JSON). """

        super(BiologicallyDerivedProductManipulation, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(BiologicallyDerivedProductManipulation, self).elementProperties()
        js.extend([
            ("description", "description", str, "string", False, None, False),
            ("timeDateTime", "timeDateTime", fhirdate.FHIRDate, "dateTime", False, "time", False),
            ("timePeriod", "timePeriod", period.Period, "Period", False, "time", False),
        ])
        return js


class BiologicallyDerivedProductProcessing(backboneelement.BackboneElement):
    """ Any processing of the product during collection.

    Any processing of the product during collection that does not change the
    fundamental nature of the product. For example adding anti-coagulants
    during the collection of Peripheral Blood Stem Cells.
    """

    resource_type = "BiologicallyDerivedProductProcessing"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.additive = None
        """ Substance added during processing.
        Type `FHIRReference` (represented as `dict` in JSON). """

        self.description = None
        """ Description of of processing.
        Type `str`. """

        self.procedure = None
        """ Procesing code.
        Type `CodeableConcept` (represented as `dict` in JSON). """

        self.timeDateTime = None
        """ Time of processing.
        Type `FHIRDate` (represented as `str` in JSON). """

        self.timePeriod = None
        """ Time of processing.
        Type `Period` (represented as `dict` in JSON). """

        super(BiologicallyDerivedProductProcessing, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(BiologicallyDerivedProductProcessing, self).elementProperties()
        js.extend([
            ("additive", "additive", fhirreference.FHIRReference, "Reference", False, None, False),
            ("description", "description", str, "string", False, None, False),
            ("procedure", "procedure", codeableconcept.CodeableConcept, "CodeableConcept", False, None, False),
            ("timeDateTime", "timeDateTime", fhirdate.FHIRDate, "dateTime", False, "time", False),
            ("timePeriod", "timePeriod", period.Period, "Period", False, "time", False),
        ])
        return js


class BiologicallyDerivedProductStorage(backboneelement.BackboneElement):
    """ Product storage.
    """

    resource_type = "BiologicallyDerivedProductStorage"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.description = None
        """ Description of storage.
        Type `str`. """

        self.duration = None
        """ Storage timeperiod.
        Type `Period` (represented as `dict` in JSON). """

        self.scale = None
        """ farenheit | celsius | kelvin.
        Type `str`. """

        self.temperature = None
        """ Storage temperature.
        Type `float`. """

        super(BiologicallyDerivedProductStorage, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(BiologicallyDerivedProductStorage, self).elementProperties()
        js.extend([
            ("description", "description", str, "string", False, None, False),
            ("duration", "duration", period.Period, "Period", False, None, False),
            ("scale", "scale", str, "code", False, None, False),
            ("temperature", "temperature", float, "decimal", False, None, False),
        ])
        return js


import sys
try:
    from . import codeableconcept
except ImportError:
    codeableconcept = sys.modules[__package__ + '.codeableconcept']
try:
    from . import fhirdate
except ImportError:
    fhirdate = sys.modules[__package__ + '.fhirdate']
try:
    from . import fhirreference
except ImportError:
    fhirreference = sys.modules[__package__ + '.fhirreference']
try:
    from . import identifier
except ImportError:
    identifier = sys.modules[__package__ + '.identifier']
try:
    from . import period
except ImportError:
    period = sys.modules[__package__ + '.period']
